import { Component, EventEmitter, Input, Output } from '@angular/core';
import * as moment from 'moment';
export class ContactsKanbanCardViewComponent {
    constructor() {
        this.onCardDetailsChange = new EventEmitter();
        this.editCardDetails = new EventEmitter();
        this.dateFormatString = 'YYYY-MM-DD';
        this.timeFormatString = 'hh:mm a';
        this.cardDetails = {
            select: false,
            id: '',
            title: '',
            accountName: '',
            contactName: '',
            phone: '',
            email: '',
            created: '',
        };
        this.dueColor = '';
        this.dueFontColor = '';
    }
    ngOnInit() {
        if (this.cardDetails.created && this.cardDetails.created !== '0000-00-00') {
            let cardDate = moment(this.cardDetails.created).endOf('day');
            let curDate = moment().endOf('day');
            let diff = cardDate.diff(curDate, 'hours');
            switch (true) {
                // red past due or due today
                case diff < 0:
                    this.dueColor = 'red';
                    this.dueFontColor = '#ffffff';
                    break;
                //due today
                case diff == 0:
                    this.dueColor = 'orange';
                    this.dueFontColor = '#ffffff';
                    break;
                // tomorrow
                case diff >= 24 && diff <= 24 * 2:
                    this.dueColor = 'yellow';
                    break;
                // this week
                case diff >= 24 * 2 && diff <= 24 * 7:
                    this.dueColor = 'green';
                    this.dueFontColor = '#ffffff';
                    break;
                // next week
                case diff >= 24 * 7 && diff <= 24 * 14:
                    this.dueColor = 'blue';
                    this.dueFontColor = '#ffffff';
                    break;
                // this month
                case diff >= 24 * 14 && diff <= 24 * 30:
                    this.dueColor = 'black';
                    this.dueFontColor = '#ffffff';
                    break;
                default:
                    this.dueColor = 'gray';
                    break;
            }
        }
    }
    onCheckBoxSelected(event) {
        this.onCardDetailsChange.emit(this.cardDetails);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
    editCard(lead) {
        this.editCardDetails.emit(lead);
    }
}
ContactsKanbanCardViewComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-contacts-kanban-card-view',
                template: "<mat-card class=\"swimlane-card\">\r\n    <mat-card-header>\r\n      <mat-card-title class=\"title-due-date\" [ngStyle]=\"{'background-color':dueColor, 'color': dueFontColor}\">Created Date: {{ getDateFormat(cardDetails.created) }}</mat-card-title>\r\n    </mat-card-header>\r\n  \r\n    <!-- <a class=\"link\" [routerLink]=\"['/products/', cardDetails?.id]\"><img mat-card-image [src]=\"cardDetails?.image\" onError=\"this.src= 'assets/images/ecommerce/placeholder-image.png'\"/></a> --> \r\n    <mat-card-content>\r\n        <div fxLayout=\"row\" class=\"art-header\">\r\n          <mat-checkbox [(ngModel)]=\"cardDetails.select\" class=\"checkbox-position\" (change)=\"onCheckBoxSelected($event)\"></mat-checkbox>      \r\n              <div fxLayout=\"column\" class=\"card-content\" [routerLink]=\"['/contacts/', cardDetails?.id]\">\r\n                <span>\r\n                  Contact Name: {{ cardDetails.contactName }} <br>\r\n                  Title: {{ cardDetails.title }} <br>\r\n                  Account Name: {{ cardDetails.accountName }} <br>\r\n                  Phone: {{ cardDetails.phone }} <br>\r\n                  Email: {{ cardDetails.email }} <br>\r\n                </span>\r\n              </div>\r\n            </div>\r\n    </mat-card-content>\r\n  \r\n  </mat-card>",
                styles: ["@import url(\"https://fonts.googleapis.com/css2?family=Roboto:wght@100;300;400;700&display=swap\");.swimlane-card{background-color:#fff;border-radius:0;border:1px solid #ddd;box-shadow:6px 1px 0 #b5b5b5;padding:0;margin:5px}.swimlane-card ::ng-deep .mat-card-header{border-bottom:1px solid #ddd}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text{padding:0;margin:0;width:100%}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text .mat-card-title{background-color:#f4ffb9;text-align:center;font-size:12px;padding:5px 0;font-weight:100;margin-bottom:0;font-weight:400}.swimlane-card ::ng-deep .mat-card-content{font-size:14px;font-weight:400;padding:10px;white-space:break-spaces}.swimlane-card ::ng-deep .mat-card-image{margin:0 auto!important;padding:10px;display:block;width:50%!important}.swimlane-card .title-due-date{font-weight:700}.cdk-drag-preview{box-sizing:border-box;border-radius:4px;box-shadow:0 5px 5px -3px rgba(0,0,0,.2),0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 2px rgba(0,0,0,.12)}.cdk-drag-placeholder{opacity:0}.cdk-drag-animating{transition:transform .25s cubic-bezier(0,0,.2,1)}.example-box:last-child{border:none}.example-list.cdk-drop-list-dragging .example-box:not(.cdk-drag-placeholder){transition:transform .25s cubic-bezier(0,0,.2,1)}.card-content{width:100%;padding:5px}.mat-star-icon{float:right}"]
            },] }
];
ContactsKanbanCardViewComponent.ctorParameters = () => [];
ContactsKanbanCardViewComponent.propDecorators = {
    onCardDetailsChange: [{ type: Output }],
    editCardDetails: [{ type: Output }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    cardDetails: [{ type: Input }]
};
//# sourceMappingURL=contacts-kanban-card-view.component.js.map