import { Component, EventEmitter, Input, Output, ViewChild } from '@angular/core';
import { MatSort } from '@angular/material/sort';
import { MatTableDataSource } from '@angular/material/table';
import * as moment from 'moment';
export class KanbanAccountListViewComponent {
    constructor() {
        this.sort = {};
        this.listDataSource = [];
        this.displayedColumns = [];
        this.pageSizeOptions = [];
        this.tableLength = 0;
        this.page = '';
        this.displayActionsBar = false;
        this.dateFormatString = 'YYYY-MM-DD';
        this.timeFormatString = 'hh:mm a';
        this.mappingFields = [];
        this.selectClicked = new EventEmitter();
        this.onColumnClick = new EventEmitter();
        this.onPaginateFire = new EventEmitter();
        this.onSortFired = new EventEmitter();
        this.selectAll = false;
        this.pageSize = 50;
    }
    ngOnInit() {
        this.dataSource = new MatTableDataSource(this.listDataSource);
        this.appendColumns();
    }
    ngOnChanges() {
        this.appendColumns();
        this.dataSource = new MatTableDataSource(this.listDataSource);
    }
    appendColumns() {
        const standardColumns = ['select'];
        standardColumns.forEach((colName) => {
            var _a;
            if (!((_a = this.displayedColumns) === null || _a === void 0 ? void 0 : _a.includes(colName))) {
                this.displayedColumns.unshift(colName);
            }
        });
    }
    /**
     * Toggles, so all checkboxes are selected.
     *
     * @returns {void}
     */
    toggleAll(selectType, checkbox, selectedRow) {
        switch (selectType) {
            case 'SINGLE':
                this.dataSource.data.find((row) => row.id === (selectedRow === null || selectedRow === void 0 ? void 0 : selectedRow.id)).select = checkbox === null || checkbox === void 0 ? void 0 : checkbox.checked;
                break;
            case 'FIRST_50':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'SELECT_ALL':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'DESELECT_ALL':
                this.selectAll = false;
                this.dataSource.data.forEach((data) => (data.select = false));
                break;
            case 'SELECT_ALL_TOGGLE':
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                selectType = this.selectAll ? 'SELECT_ALL' : 'DESELECT_ALL';
                break;
            default:
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                break;
        }
        this.selectClicked.emit({ data: this.dataSource.data, selectType });
    }
    /**
     * On column click, emit the colum name and the row selected.
     *
     * @param {AccountListMapperI} element
     * @param {string} columnName
     * @returns {void}
     */
    onColumnClicked(element, columnName) {
        this.onColumnClick.emit({ columnName, rowSelected: element });
    }
    /**
     * On paginate emit event;
     *
     * @returns {void}
     */
    paginate(event) {
        const paginateObj = {
            offset: event.pageIndex,
            limit: event.pageSize,
        };
        this.pageSize = event.pageSize;
        this.onPaginateFire.emit(paginateObj);
    }
    /**
     * On material sort fire event.
     *
     * @returns {void}
     */
    onListViewSort(event) {
        this.onSortFired.emit(event);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
}
KanbanAccountListViewComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-kanban-account-list-view',
                template: "<table mat-table [dataSource]=\"dataSource\" matSort (matSortChange)=\"onListViewSort($event)\" class=\"mat-elevation-z8\" [ngClass]=\"{'fixedHeader': displayActionsBar}\" style=\"width:100%\">\r\n\r\n  <ng-container matColumnDef=\"select\">\r\n    <th mat-header-cell  *matHeaderCellDef class=\"select-container width-120 padding-right-8\">\r\n      <div fxLayout=\"row\" fxLayoutGap=\"4px\">\r\n        <mat-checkbox (change)=\"toggleAll('SELECT_ALL_TOGGLE')\" [checked]=\"selectAll\" > </mat-checkbox>\r\n        <div class=\"arrow-down\" [matMenuTriggerFor]=\"selectAllMenu\"> </div>\r\n      </div>\r\n    </th>\r\n    <td mat-cell *matCellDef=\"let element\">\r\n      <mat-checkbox  (change)=\"toggleAll('SINGLE',$event, element)\" [checked]=\"element?.select\"> </mat-checkbox>\r\n    </td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"accountName\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'accountName' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'accountName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.accountName\"><p class=\"text-truncate\"> {{element?.accountName}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"vendorAccountNumber\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'vendorAccountNumber' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'vendorAccountNumber')\" *matCellDef=\"let element\" [matTooltip]=\"element?.vendorAccountNumber\"><p class=\"text-truncate\"> {{element?.vendorAccountNumber}} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"partnerType\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'partnerType' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'partnerType')\" *matCellDef=\"let element\" [matTooltip]=\"element?.partnerType\"><p class=\"text-truncate\"> {{element?.partnerType}} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"shipState\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'shipState' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'shipState')\" *matCellDef=\"let element\" [matTooltip]=\"element?.shipState\"><p class=\"text-truncate\"> {{element?.shipState}} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"timeZone\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'timeZone' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'timeZone')\" *matCellDef=\"let element\" [matTooltip]=\"element?.timeZone\"><p class=\"text-truncate\"> {{element?.timeZone}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"phone\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'phone' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'phone')\" *matCellDef=\"let element\" [matTooltip]=\"element?.phone\"><p class=\"text-truncate\"> {{element?.phone}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"defaultCurrency\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'defaultCurrency' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'defaultCurrency')\" *matCellDef=\"let element\" [matTooltip]=\"element?.defaultCurrency\"><p class=\"text-truncate\"> {{element?.defaultCurrency}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"fax\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'fax' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'fax')\" *matCellDef=\"let element\" [matTooltip]=\"element?.fax\"><p class=\"text-truncate\"> {{element?.fax}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"salesRep\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'salesRep' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'salesRep')\" *matCellDef=\"let element\" [matTooltip]=\"element?.salesRep\"><p class=\"text-truncate\"> {{element?.salesRep}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"productionManager\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productionManager' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productionManager')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productionManager\"><p class=\"text-truncate\"> {{element?.productionManager}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"corporateIdentityName\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'corporateIdentityName' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'corporateIdentityName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.corporateIdentityName\"><p class=\"text-truncate\"> {{element?.corporateIdentityName}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"taxExempt\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'taxExempt' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'taxExempt')\" *matCellDef=\"let element\" [matTooltip]=\"element?.taxExempt\"><p class=\"text-truncate\"> {{element?.taxExempt}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"highCreditLimit\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'highCreditLimit' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'highCreditLimit')\" *matCellDef=\"let element\" [matTooltip]=\"element?.highCreditLimit\"><p class=\"text-truncate\"> {{element?.highCreditLimit}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"customerPO\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'customerPO' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'customerPO')\" *matCellDef=\"let element\" [matTooltip]=\"element?.customerPO\"><p class=\"text-truncate\"> {{element?.customerPO}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"firstOrderDate\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'firstOrderDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'firstOrderDate')\" *matCellDef=\"let element\" [matTooltip]=\"element?.firstOrderDate\"><p class=\"text-truncate\"> {{ getDateFormat(element?.firstOrderDate) }} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"leadSource\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'leadSource' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'leadSource')\" *matCellDef=\"let element\" [matTooltip]=\"element?.leadSource\"><p class=\"text-truncate\"> {{element?.leadSource}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"industry\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'industry' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'industry')\" *matCellDef=\"let element\" [matTooltip]=\"element?.industry\"><p class=\"text-truncate\"> {{element?.industry}} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"pricingMethods\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'pricingMethods' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'pricingMethods')\" *matCellDef=\"let element\" [matTooltip]=\"element?.pricingMethods\"><p class=\"text-truncate\"> {{element?.pricingMethods}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"csr\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'csr' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'csr')\" *matCellDef=\"let element\" [matTooltip]=\"element?.csr\"><p class=\"text-truncate\"> {{element?.csr}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"parentAccount\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'parentAccount' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'parentAccount')\" *matCellDef=\"let element\" [matTooltip]=\"element?.parentAccount\"><p class=\"text-truncate\"> {{element?.parentAccount}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"alternateAccountNumber\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'alternateAccountNumber' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'alternateAccountNumber')\" *matCellDef=\"let element\" [matTooltip]=\"element?.alternateAccountNumber\"><p class=\"text-truncate\"> {{element?.alternateAccountNumber}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"rating\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'rating' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'rating')\" *matCellDef=\"let element\" [matTooltip]=\"element?.rating\"><p class=\"text-truncate\"> {{element?.rating}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"creditTerms\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'creditTerms' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'creditTerms')\" *matCellDef=\"let element\" [matTooltip]=\"element?.creditTerms\"><p class=\"text-truncate\"> {{element?.creditTerms}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"billAddress1\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'billAddress1' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'billAddress1')\" *matCellDef=\"let element\" [matTooltip]=\"element?.billAddress1\"><p class=\"text-truncate\"> {{element?.billAddress1}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"billAddress2\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'billAddress2' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'billAddress2')\" *matCellDef=\"let element\" [matTooltip]=\"element?.billAddress2\"><p class=\"text-truncate\"> {{element?.billAddress2}} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"billCity\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'billCity' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'billCity')\" *matCellDef=\"let element\" [matTooltip]=\"element?.billCity\"><p class=\"text-truncate\"> {{element?.billCity}} </p></td>\r\n  </ng-container>\r\n  <ng-container matColumnDef=\"billCountry\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'billCountry' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'billCountry')\" *matCellDef=\"let element\" [matTooltip]=\"element?.billCountry\"><p class=\"text-truncate\"> {{element?.billCountry}} </p></td>\r\n  </ng-container>\r\n  <ng-container matColumnDef=\"billPostalcode\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'billPostalcode' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'billPostalcode')\" *matCellDef=\"let element\" [matTooltip]=\"element?.billPostalcode\"><p class=\"text-truncate\"> {{element?.billPostalcode}} </p></td>\r\n  </ng-container>\r\n  <ng-container matColumnDef=\"billState\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'billState' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'billState')\" *matCellDef=\"let element\" [matTooltip]=\"element?.billState\"><p class=\"text-truncate\"> {{element?.billState}} </p></td>\r\n  </ng-container>\r\n  <ng-container matColumnDef=\"commissionGroup\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'commissionGroup' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'commissionGroup')\" *matCellDef=\"let element\" [matTooltip]=\"element?.commissionGroup\"><p class=\"text-truncate\"> {{element?.commissionGroup}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"shipAddress1\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'shipAddress1' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'shipAddress1')\" *matCellDef=\"let element\" [matTooltip]=\"element?.shipAddress1\"><p class=\"text-truncate\"> {{element?.shipAddress1}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"shipAddress2\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'shipAddress2' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'shipAddress2')\" *matCellDef=\"let element\" [matTooltip]=\"element?.shipAddress2\"><p class=\"text-truncate\"> {{element?.shipAddress2}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"shipCity\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'shipCity' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'shipCity')\" *matCellDef=\"let element\" [matTooltip]=\"element?.shipCity\"><p class=\"text-truncate\"> {{element?.shipCity}} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"shipCountry\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'shipCountry' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'shipCountry')\" *matCellDef=\"let element\" [matTooltip]=\"element?.shipCountry\"><p class=\"text-truncate\"> {{element?.shipCountry}} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"shipPostalcode\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'shipPostalcode' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'shipPostalcode')\" *matCellDef=\"let element\" [matTooltip]=\"element?.shipPostalcode\"><p class=\"text-truncate\"> {{element?.shipPostalcode}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"taxExemptCertExpDate\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'taxExemptCertExpDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'taxExemptCertExpDate')\" *matCellDef=\"let element\" [matTooltip]=\"element?.taxExemptCertExpDate\"><p class=\"text-truncate\"> {{ getDateFormat(element?.taxExemptCertExpDate) }} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"dateCreated\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'dateCreated' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dateCreated')\" *matCellDef=\"let element\" [matTooltip]=\"element?.dateCreated\"><p class=\"text-truncate\"> {{ getDateFormat(element?.dateCreated) }} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"dateModified\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'dateModified' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dateModified')\" *matCellDef=\"let element\" [matTooltip]=\"element?.dateModified\"><p class=\"text-truncate\"> {{ getDateFormat(element?.dateModified) }} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"accountType\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'accountType' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'accountType')\" *matCellDef=\"let element\" [matTooltip]=\"element?.accountType\"><p class=\"text-truncate\"> {{ element?.accountType }} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"accountExtension\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'accountExtension' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'accountExtension')\" *matCellDef=\"let element\" [matTooltip]=\"element?.accountExtension\"><p class=\"text-truncate\"> {{ element?.accountExtension }} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <tr mat-header-row *matHeaderRowDef=\"displayedColumns; sticky:true\"></tr>\r\n  <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\r\n</table>\r\n<mat-paginator [length]=\"tableLength\" [pageIndex]=\"0\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"[10,20, 50, 100]\" [showFirstLastButtons]=\"true\" (page)=\"paginate($event)\"></mat-paginator>\r\n\r\n\r\n<mat-menu #selectAllMenu=\"matMenu\">\r\n  <button mat-menu-item (click)=\"toggleAll('FIRST_50')\"> Select This Page ({{ tableLength < pageSize ? tableLength : pageSize }} ) </button>\r\n  <button mat-menu-item (click)=\"toggleAll('SELECT_ALL')\"> Select All ({{tableLength}}) </button>\r\n  <button mat-menu-item (click)=\"toggleAll('DESELECT_ALL')\"> Deselect All </button>\r\n</mat-menu>\r\n",
                styles: ["th.mat-header-cell{background-color:#fafafa;text-align:left;min-height:42px;max-width:200px;background-color:#2e75b6!important;color:#fff}td.mat-cell :not(:first-child){text-align:left;max-width:150px;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;padding-left:5px}td.mat-cell:first-of-type,td.mat-footer-cell:first-of-type,th.mat-header-cell:first-of-type{padding-left:24px!important}.center{text-align:left}tr.mat-header-row{height:40px}.pointer{cursor:pointer}.header-cell{padding-top:8px;padding-bottom:8px;font-size:14px;font-weight:400;flex-wrap:wrap}.total-price{text-align:right!important}.link{color:#2196f3;text-decoration:underline}.arrow-down{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid #fff;position:relative;top:8px;cursor:pointer}.total-width{width:100%;text-align:right!important}p{margin:0}.tasks-done{color:#8b0000;position:relative;right:3px}.tasks-done,.tasks-total{text-decoration:underline;font-size:16px}.tasks-total{color:#4d5d66}.total-header{display:flex;justify-content:flex-end;font-size:14px;font-weight:400;flex-wrap:wrap;padding-left:10px}:host ::ng-deep .mat-sort-header-arrow{color:#fff}:host ::ng-deep .select-container .mat-checkbox .mat-checkbox-frame{border-color:#fff}.activities-font{font-size:16px}.slash{font-size:22px;position:relative;bottom:3px}.favorite{top:0!important}:host ::ng-deep .mat-cell .mat-icon{position:relative;top:16px;font-size:30px}.comment-number{position:link;cursor:pointer;color:#fff;position:relative;bottom:16px;left:6px}.comment-position{left:10px!important}.color-red-500{color:#f44336}.color-orange-500{color:#ff9800}.color-blue-500{color:#2196f3}.color-pink-500{color:#e91e63}.color-purple{color:#9c27b0}.width-60{width:60px}.width-90{width:90px}.width-120{width:120px}.width-150{width:150px}.padding-right-8{padding-right:8px}.paddding-left-4{padding-left:4px}.text-align-right{text-align:right}.text-truncate{white-space:nowrap;text-overflow:ellipsis;overflow:hidden}::ng-deep th.mat-header-cell,td.mat-cell,td.mat-footer-cell{width:150px;padding-left:10px}"]
            },] }
];
KanbanAccountListViewComponent.ctorParameters = () => [];
KanbanAccountListViewComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    listDataSource: [{ type: Input }],
    displayedColumns: [{ type: Input }],
    pageSizeOptions: [{ type: Input }],
    tableLength: [{ type: Input }],
    page: [{ type: Input }],
    displayActionsBar: [{ type: Input }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    mappingFields: [{ type: Input }],
    selectClicked: [{ type: Output }],
    onColumnClick: [{ type: Output }],
    onPaginateFire: [{ type: Output }],
    onSortFired: [{ type: Output }]
};
//# sourceMappingURL=kanban-account-list-view.component.js.map