import { Component, EventEmitter, Input, Output, ViewChild } from '@angular/core';
import { MatSort } from '@angular/material/sort';
import { MatTableDataSource } from '@angular/material/table';
import * as moment from 'moment';
export class KanbanArtworkListViewComponent {
    constructor() {
        this.sort = {};
        this.listDataSource = [];
        this.displayedColumns = [];
        this.pageSizeOptions = [];
        this.tableLength = 0;
        this.page = '';
        this.displayActionsBar = false;
        this.dateFormatString = 'YYYY-MM-DD';
        this.timeFormatString = 'hh:mm a';
        this.mappingFields = [];
        this.selectClicked = new EventEmitter();
        this.onColumnClick = new EventEmitter();
        this.onPaginateFire = new EventEmitter();
        this.onSortFired = new EventEmitter();
        this.selectAll = false;
        this.pageSize = 50;
    }
    ngOnInit() {
        this.dataSource = new MatTableDataSource(this.listDataSource);
        console.log("this.dataSource", this.dataSource);
        this.appendColumns();
    }
    ngOnChanges() {
        this.appendColumns();
        this.dataSource = new MatTableDataSource(this.listDataSource);
    }
    appendColumns() {
        const standardColumns = ['select'];
        standardColumns.forEach((colName) => {
            var _a;
            if (!((_a = this.displayedColumns) === null || _a === void 0 ? void 0 : _a.includes(colName))) {
                this.displayedColumns.unshift(colName);
            }
        });
    }
    /**
     * Toggles, so all checkboxes are selected.
     *
     * @returns {void}
     */
    toggleAll(selectType, checkbox, selectedRow) {
        switch (selectType) {
            case 'SINGLE':
                this.dataSource.data.find((row) => row.id === (selectedRow === null || selectedRow === void 0 ? void 0 : selectedRow.id)).select = checkbox === null || checkbox === void 0 ? void 0 : checkbox.checked;
                break;
            case 'FIRST_50':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'SELECT_ALL':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'DESELECT_ALL':
                this.selectAll = false;
                this.dataSource.data.forEach((data) => (data.select = false));
                break;
            case 'SELECT_ALL_TOGGLE':
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                selectType = this.selectAll ? 'SELECT_ALL' : 'DESELECT_ALL';
                break;
            default:
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                break;
        }
        this.selectClicked.emit({ data: this.dataSource.data, selectType });
    }
    /**
     * On column click, emit the colum name and the row selected.
     *
     * @param {ArtworkListMapperI} element
     * @param {string} columnName
     * @returns {void}
     */
    onColumnClicked(element, columnName) {
        this.onColumnClick.emit({ columnName, rowSelected: element });
    }
    /**
     * On paginate emit event;
     *
     * @returns {void}
     */
    paginate(event) {
        const paginateObj = {
            offset: event.pageIndex,
            limit: event.pageSize,
        };
        this.pageSize = event.pageSize;
        this.onPaginateFire.emit(paginateObj);
    }
    /**
     * On material sort fire event.
     *
     * @returns {void}
     */
    onListViewSort(event) {
        this.onSortFired.emit(event);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
}
KanbanArtworkListViewComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-kanban-artwork-list-view',
                template: "<table mat-table [dataSource]=\"dataSource\" matSort (matSortChange)=\"onListViewSort($event)\" class=\"mat-elevation-z8\" [ngClass]=\"{'fixedHeader': displayActionsBar}\" style=\"width:100%\">\r\n\r\n    <ng-container matColumnDef=\"select\">\r\n      <th mat-header-cell  *matHeaderCellDef class=\"select-container width-120 padding-right-8\">\r\n        <div fxLayout=\"row\" fxLayoutGap=\"4px\">\r\n          <mat-checkbox (change)=\"toggleAll('SELECT_ALL_TOGGLE')\" [checked]=\"selectAll\" > </mat-checkbox>\r\n          <div class=\"arrow-down\" [matMenuTriggerFor]=\"selectAllMenu\"> </div>\r\n        </div>\r\n      </th>\r\n      <td mat-cell *matCellDef=\"let element\">\r\n        <mat-checkbox  (change)=\"toggleAll('SINGLE',$event, element)\" [checked]=\"element?.select\"> </mat-checkbox>\r\n      </td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"thumbnail\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'thumbnail' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'thumbnail')\" *matCellDef=\"let element\">\r\n        <img class=\"artwork-image-wide\"\r\n                [src]=\"element?.thumbnail || 'assets/images/ecommerce/product-image-placeholder.png'\"\r\n                />\r\n      </td>\r\n      <!-- <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'thumbnail')\" *matCellDef=\"let element\"> {{element?.thumbnail}}\r\n        <img class=\"artwork-image-wide\"\r\n                [src]=\"element?.thumbnail\"\r\n                [default]= \"'assets/images/ecommerce/product-image-placeholder.png'\"/>\r\n      </td> -->\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"task\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'task' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'task')\" *matCellDef=\"let element\" [matTooltip]=\"element?.task\"><p class=\"text-truncate\"> {{element?.task}} </p></td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"designNo\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'designNo' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'designNo')\" *matCellDef=\"let element\" [matTooltip]=\"element?.designNo\"><p class=\"text-truncate\">{{element?.designNo}}</p></td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"identity\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'identity' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'identity')\" *matCellDef=\"let element\"  [matTooltip]=\"element?.identity\"><p class=\"text-truncate\"> {{element?.identity}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"customerName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'customerName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'customerName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.customerName\"><p class=\"text-truncate\"> {{element?.customerName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"artworkLocation\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'artworkLocation' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'artworkLocation')\" *matCellDef=\"let element\" [matTooltip]=\"element?.artworkLocation\"><p class=\"text-truncate\"> {{element?.artworkLocation}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"designTypeName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'designTypeName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'designTypeName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.designTypeName\"><p class=\"text-truncate\"> {{element?.designTypeName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"category\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'category' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'category')\" *matCellDef=\"let element\" [matTooltip]=\"element?.category\"><p class=\"text-truncate\"> {{element?.category}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"estimated\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'estimated' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'estimated')\" *matCellDef=\"let element\" [matTooltip]=\"element?.estimated\"><p class=\"text-truncate\"> {{element?.estimated}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"dueDate\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'dueDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dueDate')\" *matCellDef=\"let element\" [matTooltip]=\"element?.dueDate\"><p class=\"text-truncate\"> {{ getDateFormat(element?.dueDate) }} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"createdDate\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'createdDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'createdDate')\" *matCellDef=\"let element\" [matTooltip]=\"element?.createdDate\"><p class=\"text-truncate\"> {{ getDateFormat(element?.createdDate) }} </p></td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"priority\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'priority' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'priority')\" *matCellDef=\"let element\" [matTooltip]=\"element?.priority\"><p class=\"text-truncate\"> {{element?.priority}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"statusName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'statusName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'statusName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.statusName\"><p class=\"text-truncate\"> {{element?.statusName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"assignee\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'assignee' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'assignee')\" *matCellDef=\"let element\" [matTooltip]=\"element?.assignee\"><p class=\"text-truncate\"> {{element?.assignee}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"projectName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'projectName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'projectName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.projectName\"><p class=\"text-truncate\"> {{element?.projectName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"dateApproved\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'dateApproved' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dateApproved')\" *matCellDef=\"let element\" [matTooltip]=\"element?.dateApproved\"><p class=\"text-truncate\"> {{ getDateFormat(element?.dateApproved) }} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"approvedBy\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'approvedBy' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'approvedBy')\" *matCellDef=\"let element\" [matTooltip]=\"element?.approvedBy\"><p class=\"text-truncate\"> {{element?.approvedBy}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"orderNum\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'orderNum' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'orderNum')\" *matCellDef=\"let element\" [matTooltip]=\"element?.orderNum\"><p class=\"text-truncate\"> {{element?.orderNum}} </p></td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"orderIdentity\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'orderIdentity' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'orderIdentity')\" *matCellDef=\"let element\" [matTooltip]=\"element?.orderIdentity\"><p class=\"text-truncate\"> {{element?.orderIdentity}} </p></td>\r\n    </ng-container>\r\n    <ng-container matColumnDef=\"artworkContactName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'artworkContactName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'artworkContactName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.artworkContactName\"><p class=\"text-truncate\"> {{element?.artworkContactName}} </p></td>\r\n    </ng-container>\r\n    <ng-container matColumnDef=\"artworkContactEmail\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'artworkContactEmail' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'artworkContactEmail')\" *matCellDef=\"let element\" [matTooltip]=\"element?.artworkContactEmail\"><p class=\"text-truncate\"> {{element?.artworkContactEmail}} </p></td>\r\n    </ng-container>\r\n    <ng-container matColumnDef=\"royaltyRetail\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'royaltyRetail' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'royaltyRetail')\" *matCellDef=\"let element\" [matTooltip]=\"element?.royaltyRetail\"><p class=\"text-truncate\"> {{element?.royaltyRetail}} </p></td>\r\n    </ng-container>\r\n    <ng-container matColumnDef=\"royaltyRetailAmountType\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'royaltyRetailAmountType' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'royaltyRetailAmountType')\" *matCellDef=\"let element\" [matTooltip]=\"element?.royaltyRetailAmountType\"><p class=\"text-truncate\"> {{element?.royaltyRetailAmountType}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"royaltyWholesale\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'royaltyWholesale' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'royaltyWholesale')\" *matCellDef=\"let element\" [matTooltip]=\"element?.royaltyWholesale\"> <p class=\"text-truncate\"> {{element?.royaltyWholesale}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"royaltyWholesaleAmountType\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'royaltyWholesaleAmountType' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'royaltyWholesaleAmountType')\" *matCellDef=\"let element\" [matTooltip]=\"element?.royaltyWholesaleAmountType\"><p class=\"text-truncate\"> {{element?.royaltyWholesaleAmountType}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"pinned\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'royaltyRetailAmountType' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'pinned')\" *matCellDef=\"let element\" [matTooltip]=\"element?.pinned\"><p class=\"text-truncate\"> {{element?.pinned}} </p></td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"salesRep\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'salesRep' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'salesRep')\" *matCellDef=\"let element\" [matTooltip]=\"element?.salesRep\"><p class=\"text-truncate\"> {{element?.salesRep}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"salesManagerName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'salesManagerName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'salesManagerName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.salesManagerName\"><p class=\"text-truncate\"> {{element?.salesManagerName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"productionManagerName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productionManagerName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productionManagerName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productionManagerName\"><p class=\"text-truncate\"> {{element?.productionManagerName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"alternateAccountNumber\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'alternateAccountNumber' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'alternateAccountNumber')\" *matCellDef=\"let element\" [matTooltip]=\"element?.alternateAccountNumber\"><p class=\"text-truncate\"> {{element?.alternateAccountNumber}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"csrName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'csrName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'csrName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.csrName\"><p class=\"text-truncate\"> {{element?.csrName}} </p></td>\r\n    </ng-container>\r\n\r\n    <tr mat-header-row *matHeaderRowDef=\"displayedColumns; sticky:true\"></tr>\r\n    <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\r\n  </table>\r\n  <mat-paginator [length]=\"tableLength\" [pageIndex]=\"0\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"[10,20, 50, 100]\" [showFirstLastButtons]=\"true\" (page)=\"paginate($event)\"></mat-paginator>\r\n\r\n\r\n  <mat-menu #selectAllMenu=\"matMenu\">\r\n    <button mat-menu-item (click)=\"toggleAll('FIRST_50')\"> Select This Page ({{ tableLength < pageSize ? tableLength : pageSize }} ) </button>\r\n    <button mat-menu-item (click)=\"toggleAll('SELECT_ALL')\"> Select All ({{tableLength}}) </button>\r\n    <button mat-menu-item (click)=\"toggleAll('DESELECT_ALL')\"> Deselect All </button>\r\n  </mat-menu>\r\n\r\n",
                styles: [".mat-table{table-layout:fixed;width:100%}th.mat-header-cell{background-color:#fafafa;text-align:left;min-height:42px;max-width:200px;background-color:#2e75b6!important;color:#fff}td.mat-cell :not(:first-child){text-align:left;max-width:150px;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;padding-left:5px}td.mat-cell:first-of-type,td.mat-footer-cell:first-of-type,th.mat-header-cell:first-of-type{padding-left:24px!important}.center{text-align:left}tr.mat-header-row{height:40px}.pointer{cursor:pointer}.header-cell{padding-top:8px;padding-bottom:8px;font-size:14px;font-weight:400;flex-wrap:wrap}.total-price{text-align:right!important}.link{color:#2196f3;text-decoration:underline}.arrow-down{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid #fff;position:relative;top:8px;cursor:pointer}.total-width{width:100%;text-align:right!important}p{margin:0}.tasks-done{color:#8b0000;position:relative;right:3px}.tasks-done,.tasks-total{text-decoration:underline;font-size:16px}.tasks-total{color:#4d5d66}.total-header{display:flex;justify-content:flex-end;font-size:14px;font-weight:400;flex-wrap:wrap;padding-left:10px}::ng-deep .mat-sort-header-arrow{color:#fff}::ng-deep .select-container .mat-checkbox .mat-checkbox-frame{border-color:#fff}.activities-font{font-size:16px}.slash{font-size:22px;position:relative;bottom:3px}.favorite{top:0!important}::ng-deep .mat-cell .mat-icon{position:relative;top:16px;font-size:30px}.comment-number{position:link;cursor:pointer;color:#fff;position:relative;bottom:16px;left:6px}.comment-position{left:10px!important}.color-red-500{color:#f44336}.color-orange-500{color:#ff9800}.color-blue-500{color:#2196f3}.color-pink-500{color:#e91e63}.color-purple{color:#9c27b0}.width-60{width:60px}.width-90{width:90px}.width-120{width:120px}.width-150{width:150px}.padding-right-8{padding-right:8px}.paddding-left-4{padding-left:4px}.text-align-right{text-align:right}.artwork-image-wide{height:auto;max-height:40px;max-width:40px}.text-truncate{white-space:nowrap;text-overflow:ellipsis;overflow:hidden}::ng-deep th.mat-header-cell,td.mat-cell,td.mat-footer-cell{width:150px;padding-left:6px}"]
            },] }
];
KanbanArtworkListViewComponent.ctorParameters = () => [];
KanbanArtworkListViewComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    listDataSource: [{ type: Input }],
    displayedColumns: [{ type: Input }],
    pageSizeOptions: [{ type: Input }],
    tableLength: [{ type: Input }],
    page: [{ type: Input }],
    displayActionsBar: [{ type: Input }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    mappingFields: [{ type: Input }],
    selectClicked: [{ type: Output }],
    onColumnClick: [{ type: Output }],
    onPaginateFire: [{ type: Output }],
    onSortFired: [{ type: Output }]
};
//# sourceMappingURL=kanban-artwork-list-view.component.js.map