import { Component, Input, Output, EventEmitter } from '@angular/core';
export class KanbanFilterBarComponent {
    constructor() {
        this.filterList = [];
        this.showUpdateSearchFlag = false;
        this.page = '';
        this.onClearAll = new EventEmitter();
        this.saveSearchResult = new EventEmitter();
        this.onRemoveFilter = new EventEmitter();
        this.onUpdateExistingSearch = new EventEmitter();
        this.mappingFields = [];
        this.removeBtn = true;
    }
    /**
     * Clears the filter list and emits result.
     *
     * @returns {void}
     */
    clearAll() {
        this.onClearAll.emit();
    }
    /**
     * Saves the search and emits result.
     *
     * @returns {void}
     */
    saveSearch() {
        this.saveSearchResult.emit(this.filterList);
    }
    /**
     * Removes the filter and emits result.
     *
     * @returns {void}
     */
    removeFilter(filter) {
        this.onRemoveFilter.emit(filter);
    }
    /**
     * Updates the saved search.
     *
     * @returns {void}
     */
    updateSavedSearch() {
        this.onUpdateExistingSearch.emit(this.filterList);
    }
}
KanbanFilterBarComponent.decorators = [
    { type: Component, args: [{
                selector: 'antera-software-kanban-filter-bar',
                template: "<div *ngIf=\"filterList?.length > 0\" fxLayout=\"row\" class=\"filter-bar-whole-container\">\r\n    <div fxLayoutAlign=\"space-between\" class=\"filter-bar-content\">\r\n        <span class=\"filter-title\"> Currently Filtering By: </span>\r\n        <div fxLayout=\"row\" class=\"chip-space-between\">\r\n            <mat-chip-list aria-labal=\"filter list\">\r\n                <mat-chip *ngFor=\"let filter of filterList;\" [removable]=\"removeBtn\" (removed)=\"removeFilter(filter)\">\r\n                 <span fxLayout=\"row\"> <p *ngIf=\"filter.key !== 'search'\" class=\"tag-key\"> {{ filter.key | orderColumnNameMapper : page : mappingFields }} </p>\r\n                  <p *ngIf=\"filter.key !== 'search'\">: </p>\r\n                  <p *ngIf=\"filter.key !== 'tag'\" class=\"tag-value\">  {{ filter.value }} </p>\r\n                  <p *ngIf=\"filter.key === 'tag'\" class=\"tag-value\">  {{ filter.optionalValue }} </p>\r\n                </span>\r\n                  <mat-icon matChipRemove *ngIf=\"removeBtn\">cancel</mat-icon> </mat-chip>\r\n            </mat-chip-list>\r\n        </div>\r\n        <div fxLayoutGap=\"6px\" class=\"btn-container\" >\r\n            <span class=\"underline pointer\" (click)=\"clearAll()\"> CLEAR ALL </span>\r\n            <span class=\"underline pointer\" (click)=\"saveSearch()\"> SAVE SEARCH</span>\r\n            <span *ngIf=\"!showUpdateSearchFlag\" class=\"underline pointer\" (click)=\"updateSavedSearch()\"> UPDATE THIS SEARCH </span>\r\n        </div>\r\n    </div>\r\n</div>\r\n",
                styles: [".filter-bar-whole-container{background-color:#f4f4f4;border-color:#000;min-height:42px;width:100%;padding-left:10px}.filter-bar-whole-container .filter-bar-content{min-width:40%;align-items:center!important;padding:5px}.filter-bar-whole-container .filter-bar-content .filter-title{color:#797979;font-size:14px;font-family:Roboto}.filter-bar-whole-container .filter-bar-content .mat-chip{background-color:#fff}.filter-bar-whole-container .filter-bar-content .chip-space-between{padding:0 10px}.filter-bar-whole-container .btn-container{min-width:20%}.tag-key{color:#008fcc}.tag-value{padding-left:3px}.pointer{cursor:pointer}.underline{text-decoration:underline}p{margin:0}"]
            },] }
];
KanbanFilterBarComponent.ctorParameters = () => [];
KanbanFilterBarComponent.propDecorators = {
    filterList: [{ type: Input }],
    showUpdateSearchFlag: [{ type: Input }],
    page: [{ type: Input }],
    onClearAll: [{ type: Output }],
    saveSearchResult: [{ type: Output }],
    onRemoveFilter: [{ type: Output }],
    onUpdateExistingSearch: [{ type: Output }],
    mappingFields: [{ type: Input }]
};
//# sourceMappingURL=kanban-filter-bar.component.js.map