import { Component, EventEmitter, Input, Output, ViewChild } from '@angular/core';
import { MatSort } from '@angular/material/sort';
import { MatTableDataSource } from '@angular/material/table';
import * as moment from 'moment';
export class KanbanOrderListViewComponent {
    constructor() {
        this.sort = {};
        this.listDataSource = [];
        this.displayedColumns = [];
        this.pageSizeOptions = [];
        this.tableLength = 0;
        this.page = '';
        this.displayActionsBar = false;
        this.dateFormatString = 'YYYY-MM-DD';
        this.timeFormatString = 'hh:mm a';
        this.mappingFields = [];
        this.selectClicked = new EventEmitter();
        this.onFavoriteToggle = new EventEmitter();
        this.onColumnClick = new EventEmitter();
        this.onPaginateFire = new EventEmitter();
        this.onSortFired = new EventEmitter();
        this.onResyncQBOStatus = new EventEmitter();
        this.totalColumnDropdownList = [];
        this.selectAll = false;
        this.colors = {
            Void: 'color-red-500',
            Pending: 'color-orange-500',
            Booked: 'color-blue-500',
            BackOrdered: 'color-pink-500',
            Partial: 'color-purple-500',
            Paid: 'color-blue-500',
            Unpaid: 'color-orange-500',
        };
        this.pageSize = 50;
        this.totalPriceSelectedColumn = { key: 'Total', value: 'totalPrice' };
    }
    ngOnInit() {
        this.dataSource = new MatTableDataSource(this.listDataSource);
        this.appendColumns();
        if (this.page === 'Orders') {
            this.totalColumnDropdownList = [{ key: 'Revenue', value: 'orderAmount' }, { key: 'Total', value: 'totalPrice' }, { key: 'Balance', value: 'balance' }];
        }
        else if (this.page === 'Quotes') {
            this.totalColumnDropdownList = [{ key: 'Total', value: 'totalPrice' }, { key: 'Balance', value: 'balance' }];
        }
    }
    ngOnChanges() {
        this.appendColumns();
        this.dataSource = new MatTableDataSource(this.listDataSource);
    }
    /**
     * This method attaches the select column no
     * matter what is passed into display columns
     *
     * @returns {void}
     */
    appendColumns() {
        const standardColumns = ['select'];
        standardColumns === null || standardColumns === void 0 ? void 0 : standardColumns.forEach((colName) => {
            var _a;
            if (!((_a = this.displayedColumns) === null || _a === void 0 ? void 0 : _a.includes(colName))) {
                this.displayedColumns.unshift(colName);
            }
        });
    }
    /**
     * Toggles, so all checkboxes are selected.
     *
     * @returns {void}
     */
    toggleAll(selectType, checkbox, selectedRow) {
        switch (selectType) {
            case 'SINGLE':
                this.dataSource.data.find((row) => row.id === (selectedRow === null || selectedRow === void 0 ? void 0 : selectedRow.id)).select = checkbox === null || checkbox === void 0 ? void 0 : checkbox.checked;
                break;
            case 'FIRST_50':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'SELECT_ALL':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'DESELECT_ALL':
                this.selectAll = false;
                this.dataSource.data.forEach((data) => (data.select = false));
                break;
            case 'SELECT_ALL_TOGGLE':
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                selectType = this.selectAll ? 'SELECT_ALL' : 'DESELECT_ALL';
                break;
            default:
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                break;
        }
        this.selectClicked.emit({ data: this.dataSource.data, selectType });
    }
    /**
     * Toggles on select of favorite.
     *
     * @param {KanbanTableI} element
     * @returns {void}
     */
    onFavoriteClick(element) {
        element.favorite = !element.favorite;
        this.onFavoriteToggle.emit(element);
    }
    /**
     * On column click, emit the colum name and the row selected.
     *
     * @param {OrderListMapperI} element
     * @param {string} columnName
     * @returns {void}
     */
    onColumnClicked(element, columnName) {
        this.onColumnClick.emit({ columnName, rowSelected: element });
    }
    /**
     * On paginate emit event;
     *
     * @returns {void}
     */
    paginate(event) {
        const paginateObj = {
            offset: event.pageIndex,
            limit: event.pageSize,
        };
        this.pageSize = event.pageSize;
        this.onPaginateFire.emit(paginateObj);
    }
    /**
     * Checks to see if divider should exist in activities column.
     *
     * @param {OrderListMapperI} tableRow
     * @returns {void}
     */
    checkShouldHaveDivider(tableRow) {
        if (!isNaN(tableRow.tasksTotal) && !isNaN(tableRow.tasksDone)) {
            return true;
        }
        return false;
    }
    /**
     * Updates the total price column based on what is selected on header
     * dropdown.
     *
     * @returns {void}
     */
    updateTotalPriceSelectedColumn(menuItem) {
        this.totalPriceSelectedColumn = menuItem;
    }
    /**
     * On material sort fire event.
     *
     * @returns {void}
     */
    onListViewSort(event) {
        this.onSortFired.emit(event);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
    resyncQBOStatus(orderId) {
        this.onResyncQBOStatus.emit(orderId);
    }
}
KanbanOrderListViewComponent.decorators = [
    { type: Component, args: [{
                selector: 'antera-software-list-view',
                template: "<table mat-table [dataSource]=\"dataSource\"  matSort (matSortChange)=\"onListViewSort($event)\" class=\"mat-elevation-z8\" [ngClass]=\"{'fixedHeader': displayActionsBar}\"   style=\"width:100%\">\r\n\r\n  <ng-container matColumnDef=\"select\" class=\"select-container\">\r\n    <th mat-header-cell  *matHeaderCellDef class=\"select-container width-120 padding-right-8\">\r\n      <div fxLayout=\"row\" fxLayoutGap=\"4px\">\r\n        <mat-checkbox (change)=\"toggleAll('SELECT_ALL_TOGGLE')\" [checked]=\"selectAll\" > </mat-checkbox>\r\n        <div class=\"arrow-down\" [matMenuTriggerFor]=\"selectAllMenu\"> </div>\r\n      </div>\r\n    </th>\r\n    <td mat-cell *matCellDef=\"let element\">\r\n      <mat-checkbox  (change)=\"toggleAll('SINGLE',$event, element)\" [checked]=\"element.select\"> </mat-checkbox>\r\n    </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"favourite\">\r\n    <th mat-header-cell *matHeaderCellDef class=\"width-60 header-cell\"></th>\r\n    <td mat-cell *matCellDef=\"let element\">\r\n      <div (click)=\"onFavoriteClick(element)\">\r\n        <mat-icon *ngIf=\"element?.favorite; else emptyStar\" aria-hidden=\"false\" class=\"pointer favorite\">star\r\n        </mat-icon>\r\n        <ng-template #emptyStar>\r\n          <mat-icon aria-hidden=\"false\" class=\"pointer favorite\">star_border</mat-icon>\r\n        </ng-template>\r\n      </div>\r\n    </td>\r\n  </ng-container>\r\n\r\n    <!-- Comment Column -->\r\n    <ng-container matColumnDef=\"comments\">\r\n      <th mat-header-cell class=\"header-cell\"  mat-sort-header *matHeaderCellDef> {{ 'comments' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell (click)=\"onColumnClicked(element, 'comments')\" class=\"comments pointer\" *matCellDef=\"let element\">\r\n          <mat-icon > mode_comment</mat-icon>\r\n           <p class=\"comment-number\" [ngClass]=\"{'comment-position': element?.comments < 10}\"> {{ element?.comments || 0 }} </p>\r\n      </td>\r\n    </ng-container>\r\n\r\n    <!-- Sync Status Column -->\r\n    <ng-container matColumnDef=\"syncStatus\">\r\n      <th mat-header-cell class=\"header-cell\" *matHeaderCellDef> {{ 'syncStatus' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"comments pointer\" *matCellDef=\"let element\">\r\n        <button class=\"resync-btn mat-button-toggle-checked\" *ngIf=\"element?.resyncEnabled\" mat-button (click)=\"resyncQBOStatus(element?.id)\" [matTooltip]=\"element.resyncMessage\" [matTooltipClass]=\"'order-row-tooltip'\" [matTooltipPosition]=\"'above'\">\r\n          <mat-icon aria-hidden=\"false\">refresh</mat-icon>\r\n        </button>\r\n      </td>\r\n    </ng-container>\r\n\r\n    <!-- Task Column -->\r\n    <ng-container matColumnDef=\"task\">\r\n      <th mat-header-cell class=\"header-cell\"  *matHeaderCellDef> Activity </th>\r\n      <td mat-cell  class=\"pointer\" *matCellDef=\"let element\">\r\n          <span *ngIf=\"element.tasksTotal > 0; else showDash\" fxLayout=\"row\" class=\"padding-left-4\">\r\n                <p class=\"tasks-done\" (click)=\"onColumnClicked(element, 'tasksDone')\"> {{element?.tasksDone }} </p>\r\n                <p *ngIf=\"checkShouldHaveDivider(element)\" class=\"slash\"> / </p>\r\n                <p (click)=\"onColumnClicked(element, 'tasksTotal')\" class=\"tasks-total\">{{element.tasksTotal}}</p>\r\n          </span>\r\n          <ng-template #showDash>\r\n            <p class=\"slash\"> / </p>\r\n          </ng-template>\r\n        </td>\r\n    </ng-container>\r\n\r\n    <!-- Account Column -->\r\n  <ng-container matColumnDef=\"accountName\">\r\n    <th mat-header-cell class=\"header-cell\"  mat-sort-header *matHeaderCellDef> {{ 'accountName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell (click)=\"onColumnClicked(element, 'accountName')\" class=\"pointer link\" *matCellDef=\"let element\" [matTooltip]=\"element.accountName\" [matTooltipClass]=\"'order-row-tooltip'\" [matTooltipPosition]=\"'above'\"> {{element.accountName}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"invoiceDate\">\r\n    <th mat-header-cell class=\"header-cell\"  mat-sort-header *matHeaderCellDef> {{ 'invoiceDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'invoiceDate')\" *matCellDef=\"let element\" [matTooltip]=\"element.invoiceDate\" [matTooltipClass]=\"'order-row-tooltip'\" [matTooltipPosition]=\"'above'\"> {{ getDateFormat(element.invoiceDate) }} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"actions\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Actions </th>x\r\n    <td mat-cell *matCellDef=\"let element\"></td>\r\n  </ng-container>\r\n\r\n  <!-- Check this  -->\r\n  <ng-container matColumnDef=\"balance\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'balance' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell *matCellDef=\"let element\">   {{element.balance | currency:'USD':'symbol':'1.0-2'}}</td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"billComplete\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'billComplete' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'billComplete')\" *matCellDef=\"let element\"> {{element.billComplete}} </td>\r\n  </ng-container>\r\n\r\n    <!-- Booked Date Column -->\r\n  <ng-container matColumnDef=\"bookedDate\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'bookedDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'bookedDate')\" *matCellDef=\"let element\">\r\n      <p *ngIf=\"element?.bookedDate\">{{ getDateFormat(element.bookedDate) }} </p> </td>\r\n  </ng-container>\r\n\r\n    <!-- Contact Column -->\r\n  <ng-container matColumnDef=\"contactName\">\r\n    <th mat-header-cell  class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'contactName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell (click)=\"onColumnClicked(element, 'contactName')\" class=\"pointer link\" *matCellDef=\"let element\"> {{element.contactName}} </td>\r\n  </ng-container>\r\n\r\n  <!-- partnerIdentityId  is there instead of corporate as bhavesh..... -->\r\n  <ng-container matColumnDef=\"partnerIdentityName\">\r\n    <th mat-header-cell class=\"header-cell\"  mat-sort-header *matHeaderCellDef> {{ 'partnerIdentityName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'partnerIdentityName')\" *matCellDef=\"let element\"> {{element.partnerIdentityName}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"corporateIdentityName\">\r\n    <th mat-header-cell class=\"header-cell\"  mat-sort-header *matHeaderCellDef> {{ 'partnerIdentityName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'partnerIdentityName')\" *matCellDef=\"let element\"> {{element.partnerIdentityName}} </td>\r\n  </ng-container>\r\n<!-- TODO: WEIRD SCENARIO ABOVE TALK TO BACKEND -->\r\n\r\n  <ng-container matColumnDef=\"creditTerms\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'creditTerms' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'creditTerms')\" *matCellDef=\"let element\"> {{element.creditTerms}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"inHandDateBy\">\r\n    <th mat-header-cell  class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'inHandDateBy' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'inHandDateBy')\" *matCellDef=\"let element\">\r\n      <p *ngIf=\"element.inHandDateBy\">{{ getDateFormat(element.inHandDateBy) }} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"customerPo\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'customerPo' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'customerPo')\" *matCellDef=\"let element\"> {{element.customerPo}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"csrName\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'csrName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'csrName')\" *matCellDef=\"let element\"> {{element.csrName}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"csr\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'csrName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'csrName')\" *matCellDef=\"let element\"> {{element.csrName}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"isRushOrder\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'inRushOrder' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'inRushOrder')\" *matCellDef=\"let element\"> {{element.inRushOrder}} </td>\r\n  </ng-container>\r\n\r\n  <!-- Identity Column -->\r\n  <ng-container matColumnDef=\"orderIdentity\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'orderIdentity' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" [matTooltip]=\"element.orderIdentity\" [matTooltipClass]=\"'order-row-tooltip'\" [matTooltipPosition]=\"'above'\" (click)=\"onColumnClicked(element, 'orderIdentity')\" *matCellDef=\"let element\"> {{element.orderIdentity}} </td>\r\n  </ng-container>\r\n\r\n  <!--  Order NO  -->\r\n  <ng-container matColumnDef=\"orderNo\">\r\n\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{page === 'Quotes' ? 'Quote #' : 'Order #'}} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'orderNo')\" *matCellDef=\"let element\"> {{element.orderNo}} </td>\r\n  </ng-container>\r\n\r\n  <!--  Summary Billing  -->\r\n  <ng-container matColumnDef=\"summaryBillingNumber\">\r\n\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'summaryBillingNumber' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'summaryBillingNumber')\" *matCellDef=\"let element\"> {{element.summaryBillingNumber}} </td>\r\n  </ng-container>\r\n\r\n    <!-- Date Column -->\r\n    <ng-container matColumnDef=\"orderDate\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{page === 'Quotes' ? 'Quote Date' : 'Order Date'}} </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'orderDate')\" *matCellDef=\"let element\">\r\n        <p *ngIf=\"element.orderDate\">{{ getDateFormat(element.orderDate) }} </p> </td>\r\n    </ng-container>\r\n\r\n    <!-- Payment Status -->\r\n    <ng-container matColumnDef=\"paymentStatus\">\r\n      <th mat-header-cell class=\"header-cell\"  mat-sort-header *matHeaderCellDef> {{ 'paymentStatus' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'paymentStatus')\" class=\"pointer\" *matCellDef=\"let element\">\r\n        <p [ngClass]=\"colors[element.paymentStatus]\"> {{element.paymentStatus}}</p>  </td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"productionManagerName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productionManagerName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productionManagerName')\" *matCellDef=\"let element\"> {{element.productionManagerName}} </td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"projectName\">\r\n      <th mat-header-cell class=\"header-cell\"  mat-sort-header *matHeaderCellDef> {{ 'projectName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'projectName')\" *matCellDef=\"let element\"> {{element.projectName}} </td>\r\n    </ng-container>\r\n\r\n    <!-- Sales Person -->\r\n    <ng-container matColumnDef=\"salesPerson\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'salesPerson' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'salesPerson')\" *matCellDef=\"let element\"> {{element.salesPerson}} </td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"shipDate\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'shipDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'shipDate')\" *matCellDef=\"let element\">\r\n        <p *ngIf=\"element.shipDate\"> {{ getDateFormat(element.shipDate) }} </p> </td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"shipVia\">\r\n      <th mat-header-cell class=\"header-cell\"  mat-sort-header *matHeaderCellDef> {{ 'shipVia' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'shipVia')\" *matCellDef=\"let element\"> {{element.shipVia}} </td>\r\n    </ng-container>\r\n\r\n    <!-- Status Column -->\r\n  <ng-container matColumnDef=\"orderStatus\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'orderStatus' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'orderStatus')\" *matCellDef=\"let element\"> {{element.orderStatus}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"orderAmount\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'orderAmount' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'orderAmount')\" *matCellDef=\"let element\"> {{element.orderAmount}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"orderNoWithPrefix\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'orderNoWithPrefix' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'orderNoWithPrefix')\" *matCellDef=\"let element\"> {{element.orderNoWithPrefix}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"alternateAccountNumber\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'alternateAccountNumber' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'alternateAccountNumber')\" *matCellDef=\"let element\"> {{element.alternateAccountNumber}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"altNumber\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'altNumber' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'altNumber')\" *matCellDef=\"let element\">\r\n      {{element.altNumber}} </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"totalPrice\">\r\n    <th mat-header-cell  *matHeaderCellDef>\r\n      <div class=\"total-header\" >\r\n        <div>{{totalPriceSelectedColumn.key}}</div>\r\n         <div class=\"arrow-down-total-price\" [matMenuTriggerFor]=\"totalPriceMenu\"> </div>\r\n      </div>\r\n     </th>\r\n    <td mat-cell class=\"text-align-right\" *matCellDef=\"let element\">\r\n\r\n      <ng-container [ngSwitch]=\"totalPriceSelectedColumn.value\">\r\n        <ng-container *ngSwitchCase=\"'totalPrice'\"> <p class=\"total-width pointer\" (click)=\"onColumnClicked(element, 'totalPrice')\"> {{element.totalPrice | currency:'USD':'symbol':'1.2-2'}} </p></ng-container>\r\n        <ng-container *ngSwitchCase=\"'balance'\">   <p class=\"total-width pointer\" (click)=\"onColumnClicked(element, 'balance')\"> {{element.balance | currency:'USD':'symbol':'1.2-2'}} </p></ng-container>\r\n        <ng-container *ngSwitchCase=\"'orderAmount'\"> <p class=\"total-width pointer\" (click)=\"onColumnClicked(element, 'orderAmount')\"> {{element.orderAmount | currency:'USD':'symbol':'1.2-2'}} </p></ng-container>\r\n      </ng-container>\r\n    </td>\r\n  </ng-container>\r\n\r\n      <!-- Type Column -->\r\n  <ng-container matColumnDef=\"orderType\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'orderType' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'orderType')\" *matCellDef=\"let element\"> {{element.orderType}} </td>\r\n  </ng-container>\r\n\r\n  <!-- Due Date Column -->\r\n  <ng-container matColumnDef=\"dueDate\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'dueDate' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dueDate')\" *matCellDef=\"let element\">\r\n      <p *ngIf=\"element.dueDate\">{{ getDateFormat(element.dueDate) }} </p> </td>\r\n  </ng-container>\r\n\r\n  <!-- Promo Item Column -->\r\n  <ng-container matColumnDef=\"isPromoItem\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'isPromoItem' | orderColumnNameMapper : page : mappingFields }} </th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'isPromoItem')\" *matCellDef=\"let element\">\r\n      <p *ngIf=\"element.isPromoItem\">{{ element.isPromoItem }} </p> </td>\r\n  </ng-container>\r\n\r\n  <tr mat-header-row *matHeaderRowDef=\"displayedColumns; sticky:true\"></tr>\r\n  <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\r\n</table>\r\n<mat-paginator [length]=\"tableLength\" [pageIndex]=\"0\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"[10,20, 50, 100]\" [showFirstLastButtons]=\"true\" (page)=\"paginate($event)\"></mat-paginator>\r\n\r\n<mat-menu #selectAllMenu=\"matMenu\">\r\n  <button mat-menu-item (click)=\"toggleAll('FIRST_50')\"> Select This Page ({{ tableLength < pageSize ? tableLength : pageSize }} ) </button>\r\n  <button mat-menu-item (click)=\"toggleAll('SELECT_ALL')\"> Select All ({{tableLength}}) </button>\r\n  <button mat-menu-item (click)=\"toggleAll('DESELECT_ALL')\"> Deselect All </button>\r\n</mat-menu>\r\n\r\n<mat-menu #totalPriceMenu=\"matMenu\">\r\n  <button mat-menu-item *ngFor=\"let menuItem of totalColumnDropdownList\" (click)=\"updateTotalPriceSelectedColumn(menuItem)\">\r\n      {{menuItem.key}}\r\n  </button>\r\n</mat-menu>\r\n",
                styles: ["th.mat-header-cell{background-color:#fafafa;text-align:left;min-height:42px;max-width:200px;background-color:#2e75b6!important;color:#fff}td.mat-cell{text-align:left;max-width:150px;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;padding-left:5px}.select-container td.mat-cell{text-align:center!important}td.mat-cell:first-of-type,td.mat-footer-cell:first-of-type,th.mat-header-cell:first-of-type{padding-left:24px!important}.center{text-align:left}tr.mat-header-row{height:40px}.pointer{cursor:pointer}.header-cell{padding-top:8px;padding-bottom:8px;font-size:14px;font-weight:400;flex-wrap:wrap}.total-price{text-align:right!important}.link{color:#2196f3;text-decoration:underline}.arrow-down{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid #fff;position:relative;top:8px;cursor:pointer}.total-width{width:100%;text-align:right!important}p{margin:0}.tasks-done{color:#8b0000;position:relative;right:3px}.tasks-done,.tasks-total{text-decoration:underline;font-size:16px}.tasks-total{color:#4d5d66}.total-header{display:flex;justify-content:flex-end;font-size:14px;font-weight:400;flex-wrap:wrap;padding-left:10px;position:relative;right:20px}:host ::ng-deep .mat-sort-header-arrow{color:#fff}:host ::ng-deep .select-container .mat-checkbox .mat-checkbox-frame{border-color:#fff}.activities-font{font-size:16px}.slash{font-size:22px;position:relative;bottom:3px}.favorite{top:0!important}:host ::ng-deep .mat-cell .mat-icon{position:relative;top:16px;font-size:30px}.comment-number{position:link;cursor:pointer;color:#fff;position:relative;bottom:16px;left:6px}.comment-position{left:10px!important}.color-red-500{color:#f44336}.color-orange-500{color:#ff9800}.color-blue-500{color:#2196f3}.color-pink-500{color:#e91e63}.color-purple{color:#9c27b0}.width-60{width:60px}.width-90{width:90px}.width-120{width:120px}.width-150{width:150px}.padding-right-8{padding-right:8px}.paddding-left-4{padding-left:4px}.text-align-right{text-align:right}.arrow-down-total-price{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid #fff;position:relative;top:6px;left:4px;cursor:pointer}.resync-btn .mat-icon{position:relative;top:2px}"]
            },] }
];
KanbanOrderListViewComponent.ctorParameters = () => [];
KanbanOrderListViewComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    listDataSource: [{ type: Input }],
    displayedColumns: [{ type: Input }],
    pageSizeOptions: [{ type: Input }],
    tableLength: [{ type: Input }],
    page: [{ type: Input }],
    displayActionsBar: [{ type: Input }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    mappingFields: [{ type: Input }],
    selectClicked: [{ type: Output }],
    onFavoriteToggle: [{ type: Output }],
    onColumnClick: [{ type: Output }],
    onPaginateFire: [{ type: Output }],
    onSortFired: [{ type: Output }],
    onResyncQBOStatus: [{ type: Output }]
};
//# sourceMappingURL=kanban-list-view.component.js.map