import { Component, EventEmitter, Input, Output } from '@angular/core';
import * as moment from 'moment';
export class KanbanProductionViewCardComponent {
    constructor() {
        this.onCardDetailsChange = new EventEmitter();
        this.pinned = new EventEmitter();
        this.isOverdue = false;
        this.dueColor = '';
        this.defaultImg = '../../placeholder-image.png';
        this.bgImageColor = '';
        this.bgContentColor = '';
        this.dateFormatString = 'DD/MM/YYYY';
        this.timeFormatString = 'hh:mm a';
        this.cardToShow = {};
        this.cardDetails = {
            select: false,
            id: '',
            customerName: '',
            job: '',
            order: '',
            type: '',
            product: '',
            image: '',
            dueDate: '',
            machineId: '',
            machineName: '',
            scheduleDate: '',
            status: '',
            quantity: '',
            pinned: false,
            statusId: '',
            statusName: '',
            batchMaster: 0,
            batchJobs: []
        };
        this.dueFontColor = '';
    }
    ngOnInit() {
        var _a;
        this.cardToShow = Object.assign({}, this.cardDetails);
        if (this.cardToShow.batchMaster && !this.cardToShow.order && ((_a = this.cardToShow.batchJobs) === null || _a === void 0 ? void 0 : _a.length)) {
            const firstBatch = this.cardToShow.batchJobs[0];
            const { orderName, customerName, dueDate } = firstBatch;
            this.cardToShow.order = orderName || '';
            this.cardToShow.job = this.cardToShow.order;
            this.cardToShow.customerName = customerName || '';
            if (!this.cardToShow.dueDate || this.cardToShow.dueDate === '0000-00-00') {
                this.cardToShow.dueDate = dueDate === '0000-00-00' ? '' : dueDate;
            }
        }
        if (this.cardToShow.dueDate && this.cardToShow.dueDate !== '0000-00-00') {
            let cardDate = moment(this.cardToShow.dueDate).endOf('day');
            let curDate = moment().endOf('day');
            let diff = cardDate.diff(curDate, 'hours');
            switch (true) {
                // red past due or due today
                case diff < 0:
                    this.dueColor = 'red';
                    this.dueFontColor = '#ffffff';
                    break;
                //due today
                case diff == 0:
                    this.dueColor = 'orange';
                    this.dueFontColor = '#ffffff';
                    break;
                // tomorrow
                case diff >= 24 && diff <= 24 * 2:
                    this.dueColor = 'yellow';
                    this.dueFontColor = '#000000';
                    break;
                // this week
                case diff >= 24 * 2 && diff <= 24 * 7:
                    this.dueColor = 'green';
                    this.dueFontColor = '#ffffff';
                    break;
                // next week
                case diff >= 24 * 7 && diff <= 24 * 14:
                    this.dueColor = 'blue';
                    this.dueFontColor = '#ffffff';
                    break;
                // this month
                case diff >= 24 * 14 && diff <= 24 * 30:
                    this.dueColor = 'black';
                    this.dueFontColor = '#ffffff';
                    break;
                default:
                    this.dueColor = 'gray';
                    this.dueFontColor = '#000000';
                    break;
            }
        }
    }
    onPin(ev) {
        ev.stopPropagation();
        this.cardToShow.pinned = !this.cardToShow.pinned;
        this.pinned.emit(this.cardToShow);
    }
    onCheckBoxSelected(event) {
        this.onCardDetailsChange.emit(this.cardToShow);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
}
KanbanProductionViewCardComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-kanban-production-view-card',
                template: "<mat-card class=\"swimlane-card\">\r\n  <mat-card-header>\r\n    <mat-card-title class=\"title-due-date\" [ngStyle]=\"{'background-color':dueColor, 'color': dueFontColor}\">Due Date: {{ getDateFormat(cardToShow.dueDate) }}</mat-card-title>\r\n  </mat-card-header>\r\n\r\n  <a class=\"link\" [routerLink]=\"['/productions/', cardToShow?.id]\"><img mat-card-image [src]=\"cardToShow?.image\" onError=\"this.src= 'assets/images/ecommerce/placeholder-image.png'\"/></a>\r\n  <mat-card-content>\r\n      <div fxLayout=\"row\" class=\"art-header\" (click)=\"edit(card)\">\r\n        <mat-checkbox *ngIf=\"!cardToShow.batchMaster\" [(ngModel)]=\"cardToShow.select\" class=\"checkbox-position\" (change)=\"onCheckBoxSelected($event)\"></mat-checkbox>\r\n            <div fxLayout=\"column\" class=\"card-content\">\r\n              <span>\r\n                 {{ cardToShow.customerName }} <br>\r\n                Job# {{ cardToShow.job }} <br>\r\n                Order# {{ cardToShow.order }} <br>\r\n                Type: {{ cardToShow.type }} <br>\r\n                Product: {{ cardToShow.product }}<br>\r\n              </span>\r\n            </div>\r\n            <span class=\"mat-star-icon\"><a aria-label=\"pin\" (click)=\"onPin($event)\"><mat-icon *ngIf=\"cardToShow.pinned\">star</mat-icon><mat-icon *ngIf=\"!cardToShow.pinned\">star_border</mat-icon></a></span>\r\n        </div>\r\n  </mat-card-content>\r\n\r\n</mat-card>\r\n",
                styles: ["@import url(\"https://fonts.googleapis.com/css2?family=Roboto:wght@100;300;400;700&display=swap\");.swimlane-card{background-color:#fff;border-radius:0;border:1px solid #ddd;box-shadow:6px 1px 0 #b5b5b5;padding:0;margin:5px}.swimlane-card ::ng-deep .mat-card-header{border-bottom:1px solid #ddd}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text{padding:0;margin:0;width:100%}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text .mat-card-title{background-color:#f4ffb9;text-align:center;font-size:12px;padding:5px 0;font-weight:100;margin-bottom:0;font-weight:400}.swimlane-card ::ng-deep .mat-card-content{font-size:14px;font-weight:400;padding:10px;white-space:break-spaces}.swimlane-card ::ng-deep .mat-card-image{margin:0 auto!important;padding:10px;display:block;width:50%!important}.swimlane-card .title-due-date{font-weight:700}.cdk-drag-preview{box-sizing:border-box;border-radius:4px;box-shadow:0 5px 5px -3px rgba(0,0,0,.2),0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 2px rgba(0,0,0,.12)}.cdk-drag-placeholder{opacity:0}.cdk-drag-animating{transition:transform .25s cubic-bezier(0,0,.2,1)}.example-box:last-child{border:none}.example-list.cdk-drop-list-dragging .example-box:not(.cdk-drag-placeholder){transition:transform .25s cubic-bezier(0,0,.2,1)}.card-content{width:100%;padding:5px}.mat-star-icon{float:right}"]
            },] }
];
KanbanProductionViewCardComponent.ctorParameters = () => [];
KanbanProductionViewCardComponent.propDecorators = {
    onCardDetailsChange: [{ type: Output }],
    pinned: [{ type: Output }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    cardDetails: [{ type: Input }]
};
//# sourceMappingURL=kanban-production-view-card.component.js.map