import { Component, EventEmitter, Input, Output, ViewChild } from '@angular/core';
import { MatSort } from '@angular/material/sort';
import { MatTableDataSource } from '@angular/material/table';
import * as moment from 'moment';
export class KanbanProductionsListViewComponent {
    constructor() {
        this.sort = {};
        this.listDataSource = [];
        this.displayedColumns = [];
        this.pageSizeOptions = [];
        this.tableLength = 0;
        this.page = '';
        this.displayActionsBar = false;
        this.selectClicked = new EventEmitter();
        this.onColumnClick = new EventEmitter();
        this.onPaginateFire = new EventEmitter();
        this.onSortFired = new EventEmitter();
        this.selectAll = false;
        this.pageSize = 50;
        this.dateFormatString = 'DD/MM/YYYY';
        this.timeFormatString = 'hh:mm a';
        console.log("KanbanProductionsListViewComponent Hello");
    }
    ngOnInit() {
        this.dataSource = new MatTableDataSource(this.listDataSource);
        console.log("this.dataSource", this.dataSource);
        this.appendColumns();
    }
    ngOnChanges() {
        this.appendColumns();
        this.dataSource = new MatTableDataSource(this.listDataSource);
    }
    appendColumns() {
        const standardColumns = ['select'];
        standardColumns.forEach((colName) => {
            var _a;
            if (!((_a = this.displayedColumns) === null || _a === void 0 ? void 0 : _a.includes(colName))) {
                this.displayedColumns.unshift(colName);
            }
        });
    }
    /**
     * Toggles, so all checkboxes are selected.
     *
     * @returns {void}
     */
    toggleAll(selectType, checkbox, selectedRow) {
        switch (selectType) {
            case 'SINGLE':
                this.dataSource.data.find((row) => row.id === (selectedRow === null || selectedRow === void 0 ? void 0 : selectedRow.id)).select = checkbox === null || checkbox === void 0 ? void 0 : checkbox.checked;
                break;
            case 'FIRST_50':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'SELECT_ALL':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'DESELECT_ALL':
                this.selectAll = false;
                this.dataSource.data.forEach((data) => (data.select = false));
                break;
            case 'SELECT_ALL_TOGGLE':
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                selectType = this.selectAll ? 'SELECT_ALL' : 'DESELECT_ALL';
                break;
            default:
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                break;
        }
        this.selectClicked.emit({ data: this.dataSource.data, selectType });
    }
    /**
     * On column click, emit the colum name and the row selected.
     *
     * @param {ProductionListMapperI} element
     * @param {string} columnName
     * @returns {void}
     */
    onColumnClicked(element, columnName) {
        this.onColumnClick.emit({ columnName, rowSelected: element });
    }
    /**
     * On paginate emit event;
     *
     * @returns {void}
     */
    paginate(event) {
        const paginateObj = {
            offset: event.pageIndex,
            limit: event.pageSize,
        };
        this.pageSize = event.pageSize;
        this.onPaginateFire.emit(paginateObj);
    }
    /**
     * On material sort fire event.
     *
     * @returns {void}
     */
    onListViewSort(event) {
        this.onSortFired.emit(event);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
}
KanbanProductionsListViewComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-kanban-productions-list-view',
                template: "<table mat-table [dataSource]=\"dataSource\" matSort (matSortChange)=\"onListViewSort($event)\" class=\"mat-elevation-z8\" style=\"width:100%\">\r\n\r\n    <ng-container matColumnDef=\"select\">\r\n      <th mat-header-cell  *matHeaderCellDef class=\"select-container width-120 padding-right-8\">\r\n        <div fxLayout=\"row\" fxLayoutGap=\"4px\">\r\n          <mat-checkbox (change)=\"toggleAll('SELECT_ALL_TOGGLE')\" [checked]=\"selectAll\" > </mat-checkbox>\r\n          <div class=\"arrow-down\" [matMenuTriggerFor]=\"selectAllMenu\"> </div>\r\n        </div>\r\n      </th>\r\n      <td mat-cell *matCellDef=\"let element\">\r\n        <mat-checkbox  (change)=\"toggleAll('SINGLE',$event, element)\" [checked]=\"element?.select\"> </mat-checkbox>\r\n      </td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"customerName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Customer </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'customerName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.customerName\">\r\n        <p class=\"text-truncate\">\r\n          <ng-container *ngIf='element.batchMaster && !element.order && element.batchJobs?.length && element.batchJobs[0]; else childNode'>\r\n            {{element?.batchJobs[0].customerName}}\r\n          </ng-container>\r\n          <ng-template #childNode>\r\n            {{element?.customerName}}\r\n          </ng-template>\r\n        </p>\r\n      </td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"orderName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Order </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'orderName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.orderName\">\r\n        <p class=\"text-truncate\">\r\n          <ng-container *ngIf='element.batchMaster && !element.order && element.batchJobs?.length && element.batchJobs[0]; else childNode'>\r\n            Batch# {{element?.batchJobs[0].orderName}}\r\n          </ng-container>\r\n          <ng-template #childNode>\r\n            {{element?.orderName}}\r\n          </ng-template>\r\n        </p>\r\n      </td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"decoTypeName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Decoration Type </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'decoTypeName')\" *matCellDef=\"let element\"  [matTooltip]=\"element?.decoTypeName\"><p class=\"text-truncate\"> {{element?.decoTypeName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"decorationGroup\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Decoration Group </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'decorationGroup')\" *matCellDef=\"let element\"  [matTooltip]=\"element?.decorationGroup\"><p class=\"text-truncate\"> {{element?.decorationGroup}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"productName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Product Name </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productName\"><p class=\"text-truncate\"> {{element?.productName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"machineName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Equipment </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'machineName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.machineName\"><p class=\"text-truncate\"> {{element?.machineName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"variationName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Variation </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'variationName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.variationName\"><p class=\"text-truncate\"> {{element?.variationName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"statusName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Status </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'statusName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.statusName\"><p class=\"text-truncate\"> {{element?.statusName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"vendorName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Vendor </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'vendorName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.vendorName\">\r\n        <p class=\"text-truncate\">\r\n          <ng-container *ngIf='element.batchMaster && !element.order && element.batchJobs?.length && element.batchJobs[0]; else childNode'>\r\n            {{element?.batchJobs[0].vendorName}}\r\n          </ng-container>\r\n          <ng-template #childNode>\r\n            {{element?.vendorName}}\r\n          </ng-template>\r\n        </p>\r\n      </td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"detailName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Decoration Detail </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'detailName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.detailName\"><p class=\"text-truncate\"> {{element?.detailName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"qty\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Quantity </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'qty')\" *matCellDef=\"let element\" [matTooltip]=\"element?.qty\"><p class=\"text-truncate\"> {{element?.qty}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"priorityName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Priority </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'priorityName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.priorityName\"><p class=\"text-truncate\"> {{element?.priorityName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"color\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Color </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'color')\" *matCellDef=\"let element\" [matTooltip]=\"element?.color\"><p class=\"text-truncate\"> {{element?.color}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"size\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Size </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'size')\" *matCellDef=\"let element\" [matTooltip]=\"element?.size\"><p class=\"text-truncate\"> {{element?.size}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"detailCount\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Decoration Detail Count </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'detailCount')\" *matCellDef=\"let element\" [matTooltip]=\"element?.detailCount\"><p class=\"text-truncate\"> {{element?.detailCount}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"detailDescription\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Decoration Detail Desc </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'detailDescription')\" *matCellDef=\"let element\" [matTooltip]=\"element?.detailDescription\"><p class=\"text-truncate\"> {{element?.detailDescription}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"hours\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Hours </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'hours')\" *matCellDef=\"let element\" [matTooltip]=\"element?.hours\"><p class=\"text-truncate\"> {{element?.hours}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"due\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Due </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'due')\" *matCellDef=\"let element\" [matTooltip]=\"element?.due\"><p class=\"text-truncate\"> {{getDateFormat(element?.due)}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"productionRate\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Production Rate </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productionRate')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productionRate\"><p class=\"text-truncate\"> {{element?.productionRate}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"workOrderNo\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Work Order # </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'workOrderNo')\" *matCellDef=\"let element\" [matTooltip]=\"element?.workOrderNo\">\r\n        <p class=\"text-truncate\">\r\n          <ng-container *ngIf='element.batchMaster && !element.order && element.batchJobs?.length && element.batchJobs[0]; else childNode'>\r\n            {{element?.batchJobs[0].workOrderNo}}\r\n          </ng-container>\r\n          <ng-template #childNode>\r\n            {{element?.workOrderNo}}\r\n          </ng-template>\r\n        </p>\r\n      </td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"action\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Action </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'action')\" *matCellDef=\"let element\" [matTooltip]=\"element?.action\"><p class=\"text-truncate\"> {{element?.action}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"scheduleDate\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> Schedule Date </th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'scheduleDate')\" *matCellDef=\"let element\" [matTooltip]=\"element?.action\"><p class=\"text-truncate\"> {{ getDateFormat(element?.scheduleDate) }}</p></td>\r\n    </ng-container>\r\n\r\n    <tr mat-header-row *matHeaderRowDef=\"displayedColumns; sticky:true\"></tr>\r\n    <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\r\n  </table>\r\n  <mat-paginator [length]=\"tableLength\" [pageIndex]=\"0\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"[10,20, 50, 100]\" [showFirstLastButtons]=\"true\" (page)=\"paginate($event)\"></mat-paginator>\r\n\r\n\r\n  <mat-menu #selectAllMenu=\"matMenu\">\r\n    <button mat-menu-item (click)=\"toggleAll('FIRST_50')\"> Select This Page ({{ tableLength < pageSize ? tableLength : pageSize }} ) </button>\r\n    <button mat-menu-item (click)=\"toggleAll('SELECT_ALL')\"> Select All ({{tableLength}}) </button>\r\n    <button mat-menu-item (click)=\"toggleAll('DESELECT_ALL')\"> Deselect All </button>\r\n  </mat-menu>\r\n\r\n",
                styles: [".mat-table{table-layout:fixed;width:100%}th.mat-header-cell{background-color:#fafafa;text-align:left;min-height:42px;max-width:200px;background-color:#2e75b6!important;color:#fff}td.mat-cell :not(:first-child){text-align:left;max-width:150px;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;padding-left:5px}td.mat-cell:first-of-type,td.mat-footer-cell:first-of-type,th.mat-header-cell:first-of-type{padding-left:24px!important}.center{text-align:left}tr.mat-header-row{height:40px}.pointer{cursor:pointer}.header-cell{padding-top:8px;padding-bottom:8px;font-size:14px;font-weight:400;flex-wrap:wrap}.total-price{text-align:right!important}.link{color:#2196f3;text-decoration:underline}.arrow-down{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid #fff;position:relative;top:8px;cursor:pointer}.total-width{width:100%;text-align:right!important}p{margin:0}.tasks-done{color:#8b0000;position:relative;right:3px}.tasks-done,.tasks-total{text-decoration:underline;font-size:16px}.tasks-total{color:#4d5d66}.total-header{display:flex;justify-content:flex-end;font-size:14px;font-weight:400;flex-wrap:wrap;padding-left:10px}::ng-deep .mat-sort-header-arrow{color:#fff}::ng-deep .select-container .mat-checkbox .mat-checkbox-frame{border-color:#fff}.activities-font{font-size:16px}.slash{font-size:22px;position:relative;bottom:3px}.favorite{top:0!important}::ng-deep .mat-cell .mat-icon{position:relative;top:16px;font-size:30px}.comment-number{position:link;cursor:pointer;color:#fff;position:relative;bottom:16px;left:6px}.comment-position{left:10px!important}.color-red-500{color:#f44336}.color-orange-500{color:#ff9800}.color-blue-500{color:#2196f3}.color-pink-500{color:#e91e63}.color-purple{color:#9c27b0}.width-60{width:60px}.width-90{width:90px}.width-120{width:120px}.width-150{width:150px}.padding-right-8{padding-right:8px}.paddding-left-4{padding-left:4px}.text-align-right{text-align:right}.artwork-image-wide{height:auto;max-height:40px;max-width:40px}.text-truncate{white-space:nowrap;text-overflow:ellipsis;overflow:hidden}::ng-deep th.mat-header-cell,td.mat-cell,td.mat-footer-cell{width:150px;padding-left:6px}"]
            },] }
];
KanbanProductionsListViewComponent.ctorParameters = () => [];
KanbanProductionsListViewComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    listDataSource: [{ type: Input }],
    displayedColumns: [{ type: Input }],
    pageSizeOptions: [{ type: Input }],
    tableLength: [{ type: Input }],
    page: [{ type: Input }],
    displayActionsBar: [{ type: Input }],
    selectClicked: [{ type: Output }],
    onColumnClick: [{ type: Output }],
    onPaginateFire: [{ type: Output }],
    onSortFired: [{ type: Output }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }]
};
//# sourceMappingURL=kanban-productions-list-view.component.js.map