import { Component, EventEmitter, Input, Output, ViewChild } from '@angular/core';
import { MatSort } from '@angular/material/sort';
import { MatTableDataSource } from '@angular/material/table';
import * as moment from 'moment';
export class KanbanProductsListComponent {
    // @Input() public ds: any;
    // @Input() public columns: any;
    constructor() {
        this.sort = {};
        this.listDataSource = [];
        this.displayedColumns = [];
        this.pageSizeOptions = [];
        this.tableLength = 0;
        this.page = '';
        this.displayActionsBar = false;
        this.dateFormatString = 'YYYY-MM-DD';
        this.timeFormatString = 'hh:mm a';
        this.mappingFields = [];
        this.selectClicked = new EventEmitter();
        this.onFavoriteToggle = new EventEmitter();
        this.onColumnClick = new EventEmitter();
        this.onPaginateFire = new EventEmitter();
        this.onSortFired = new EventEmitter();
        this.totalColumnDropdownList = [];
        this.selectAll = false;
        this.pageSize = 50;
    }
    ngOnInit() {
        this.dataSource = new MatTableDataSource(this.listDataSource);
        // this.dataSource = new MatTableDataSource(this.ds);
        // this.displayedColumns = this.columns;
    }
    ngOnChanges() {
        this.dataSource = new MatTableDataSource(this.listDataSource);
    }
    paginate(event) {
        const paginateObj = {
            offset: event.pageIndex,
            limit: event.pageSize,
        };
        this.pageSize = event.pageSize;
        this.onPaginateFire.emit(paginateObj);
    }
    onColumnClicked(element, columnName) {
        this.onColumnClick.emit({ columnName, rowSelected: element });
    }
    toggleAll(selectType, checkbox, selectedRow) {
        switch (selectType) {
            case 'SINGLE':
                this.dataSource.data.find((row) => row.id === (selectedRow === null || selectedRow === void 0 ? void 0 : selectedRow.id)).select = checkbox === null || checkbox === void 0 ? void 0 : checkbox.checked;
                break;
            case 'FIRST_50':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'SELECT_ALL':
                // Special scenario need to ask bhavesh how to distinguish all and first 50.
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'DESELECT_ALL':
                this.selectAll = false;
                this.dataSource.data.forEach((data) => (data.select = false));
                break;
            case 'SELECT_ALL_TOGGLE':
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                selectType = this.selectAll ? 'SELECT_ALL' : 'DESELECT_ALL';
                break;
            default:
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                break;
        }
        this.selectClicked.emit({ data: this.dataSource.data, selectType });
    }
    onListViewSort(event) {
        this.onSortFired.emit(event);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
    processImageFromImaginary(imageUrl) {
        let imageFromImaginary = imageUrl;
        if (imageFromImaginary && imageFromImaginary.indexOf('cdnl.sanmar.com') > 0) {
            const operations = encodeURI(JSON.stringify([
                {
                    'operation': 'thumbnail',
                    'params': {
                        'width': 175,
                        'background': '255,255,255',
                        'type': 'jpeg',
                        'quality': 100,
                    }
                },
                {
                    'operation': 'convert',
                    'params': {
                        'type': 'jpeg',
                        'quality': 100,
                    }
                }
            ]));
            imageFromImaginary = `https://h4x0rt3hp74n37L4vv7.anterasaas.com/api/v1/imaginary/pipeline?url=${encodeURIComponent(imageFromImaginary)}&operations=${operations}`;
        }
        return imageFromImaginary;
    }
}
KanbanProductsListComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-kanban-products-list',
                template: "<table mat-table [dataSource]=\"dataSource\" matSort (matSortChange)=\"onListViewSort($event)\" class=\"mat-elevation-z8\"  style=\"width:100%\">\r\n\r\n  <ng-container matColumnDef=\"select\">\r\n    <th mat-header-cell  *matHeaderCellDef class=\"select-container width-120 padding-right-8\">\r\n      <div fxLayout=\"row\" fxLayoutGap=\"4px\">\r\n        <mat-checkbox (change)=\"toggleAll('SELECT_ALL_TOGGLE')\" [checked]=\"selectAll\" > </mat-checkbox>\r\n        <div class=\"arrow-down\" [matMenuTriggerFor]=\"selectAllMenu\"> </div>\r\n      </div>\r\n    </th>\r\n    <td mat-cell *matCellDef=\"let element\">\r\n      <mat-checkbox  (change)=\"toggleAll('SINGLE',$event, element)\" [checked]=\"element?.select\"> </mat-checkbox>\r\n    </td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"productId\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productId' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productId')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productId\"><p class=\"text-truncate\"> {{element?.productId}} </p></td>\r\n  </ng-container>\r\n  <ng-container matColumnDef=\"image\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  </th>\r\n    <td mat-cell *matCellDef=\"let element\">\r\n      <!-- <img *ngIf=\"element.MediaContent[0]\"\r\n           class=\"product-image-wide\"\r\n           alt=\"{{element.productName}}\"\r\n           src=\"{{element.MediaContent[0].url}}\"\r\n           *ngIf=\"element.MediaContent && element.MediaContent[0] && element.MediaContent[0].url\" src=\"processImageFromImaginary(element.MediaContent[0].url)\"\r\n      /> -->\r\n      <img class=\"product-image-wide\"\r\n           alt=\"{{element.productName}}\"\r\n           *ngIf=\"element.MediaContent && element.MediaContent[0] && element.MediaContent[0].url\" [src]=\"processImageFromImaginary(element.MediaContent[0].url)\"\r\n      />\r\n    </td>\r\n\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"productName\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productName\"><p class=\"text-truncate\"> {{element?.productName}} </p></td>\r\n  </ng-container>\r\n\r\n\r\n  <ng-container matColumnDef=\"inhouseId\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'inhouseId' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'inhouseId')\" *matCellDef=\"let element\" [matTooltip]=\"element?.inhouseId\"><p class=\"text-truncate\"> {{element?.inhouseId}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"productType\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productTypeName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productTypeName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productTypeName\"><p class=\"text-truncate\"> {{element?.productTypeName}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"storeNames\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'storeNames' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'storeNames')\" *matCellDef=\"let element\" [matTooltip]=\"element?.storeNames\">\r\n      <div>\r\n        <p *ngIf=\"element?.StoreArray.length == 0\" class=\"text-truncate\">None</p>\r\n        <mat-chip-list *ngIf=\"element?.StoreArray.length == 1\">\r\n            <mat-chip>{{element?.StoreArray[0].store}}</mat-chip>\r\n        </mat-chip-list>\r\n        <mat-chip-list *ngIf=\"element?.StoreArray.length > 1\">\r\n            <mat-chip *ngFor=\"let store of element?.StoreArray\" matTooltip=\"{{store.store}}\">{{store.store | slice:0:1}}</mat-chip>\r\n        </mat-chip-list>\r\n    </div>\r\n    </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"vendorName\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'vendorName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'vendorName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.vendorName\"><p class=\"text-truncate\"> {{element?.vendorName}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"categoryName\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'categoryName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'categoryName')\" *matCellDef=\"let element\"><!-- <p class=\"text-truncate\"> {{element?.categoryName}} </p> -->\r\n      <div>\r\n        <p *ngIf=\"element?.ProductCategoryArray.length == 0\" class=\"text-truncate\">None</p>\r\n        <mat-chip-list *ngIf=\"element?.ProductCategoryArray.length == 1\">\r\n            <mat-chip>{{element?.ProductCategoryArray[0]}}</mat-chip>\r\n        </mat-chip-list>\r\n        <mat-chip-list *ngIf=\"element?.ProductCategoryArray.length > 1\">\r\n            <mat-chip *ngFor=\"let category of element?.ProductCategoryArray\" matTooltip=\"{{category}}\">{{category | slice:0:1}}</mat-chip>\r\n        </mat-chip-list>\r\n    </div>\r\n    </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"expirationDate\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'expirationDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'expirationDate')\" *matCellDef=\"let element\" [matTooltip]=\"element?.expirationDate\"><p class=\"text-truncate\"> {{ getDateFormat(element?.expirationDate) }} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"source\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'source' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'source')\" *matCellDef=\"let element\" [matTooltip]=\"element?.source\"><p class=\"text-truncate\"> {{element?.source}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"sourceProductSku\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>  {{ 'sourceProductSku' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'sourceProductSku')\" *matCellDef=\"let element\" [matTooltip]=\"element?.sourceProductSku\"><p class=\"text-truncate\"> {{element?.sourceProductSku}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"dateCreated\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'dateCreated' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dateCreated')\" *matCellDef=\"let element\" [matTooltip]=\"element?.dateCreated\"><p class=\"text-truncate\"> {{ getDateFormat(element?.dateCreated) }} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"dateModified\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'dateModified' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dateModified')\" *matCellDef=\"let element\" [matTooltip]=\"element?.dateModified\"><p class=\"text-truncate\"> {{ getDateFormat(element?.dateModified) }} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"catalogYear\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'catalogYear' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'catalogYear')\" *matCellDef=\"let element\" [matTooltip]=\"element?.catalogYear\"><p class=\"text-truncate\"> {{element?.catalogYear}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"poType\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'poType' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'poType')\" *matCellDef=\"let element\" [matTooltip]=\"element?.poType\"><p class=\"text-truncate\"> {{element?.poType}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"specialPrice\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'specialPrice' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'specialPrice')\" *matCellDef=\"let element\" [matTooltip]=\"element?.specialPrice\"><p class=\"text-truncate\"> {{element?.specialPrice}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"productChannel\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productChannel' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productChannel')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productChannel\"><p class=\"text-truncate\"> {{element?.productChannel}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"prodStatus\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'prodStatus' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'prodStatus')\" *matCellDef=\"let element\" [matTooltip]=\"element?.prodStatus\"><p class=\"text-truncate\"> {{element?.prodStatus}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"prodKind\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'prodKind' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'prodKind')\" *matCellDef=\"let element\" [matTooltip]=\"element?.prodKind\"><p class=\"text-truncate\"> {{element?.prodKind}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"msrp\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'msrp' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'msrp')\" *matCellDef=\"let element\" [matTooltip]=\"element?.msrp\"><p class=\"text-truncate\"> {{element?.msrp}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"calculatorType\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'calculatorType' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'calculatorType')\" *matCellDef=\"let element\" [matTooltip]=\"element?.calculatorType\"><p class=\"text-truncate\"> {{element?.calculatorType}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"customerName\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'customerName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'customerName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.customerName\"><p class=\"text-truncate\"> {{element?.customerName}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"countryOrigin\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'countryOrigin' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'countryOrigin')\" *matCellDef=\"let element\" [matTooltip]=\"element?.countryOrigin\"><p class=\"text-truncate\"> {{element?.countryOrigin}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"assignedUserName\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'assignedUserName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'assignedUserName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.assignedUserName\"><p class=\"text-truncate\"> {{element?.assignedUserName}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"productOrderType\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productOrderType' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productOrderType')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productOrderType\"><p class=\"text-truncate\"> {{element?.productOrderType}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"manufacturerName\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'manufacturerName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'manufacturerName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.manufacturerName\"><p class=\"text-truncate\"> {{element?.manufacturerName}} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"autoPullEvents\">\r\n    <th mat-header-cell class=\"header-cell\" *matHeaderCellDef> {{ 'autoPullEvents' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'autoPullEvents')\" *matCellDef=\"let element\">\r\n      <div>\r\n        <p *ngIf=\"element?.SystemEventArray.length == 0\" class=\"text-truncate\">None</p>\r\n        <mat-chip-list *ngIf=\"element?.SystemEventArray.length == 1\">\r\n            <mat-chip>{{element?.SystemEventArray[0]}}</mat-chip>\r\n        </mat-chip-list>\r\n        <mat-chip-list *ngIf=\"element?.SystemEventArray.length > 1\">\r\n            <mat-chip *ngFor=\"let systemEvent of element?.SystemEventArray\" matTooltip=\"{{systemEvent}}\">{{systemEvent}}</mat-chip>\r\n        </mat-chip-list>\r\n    </div>\r\n    </td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef=\"productionTime\">\r\n    <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productionTime' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productionTime')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productionTime\"><p class=\"text-truncate\"> {{element?.productionTime}} </p></td>\r\n  </ng-container>\r\n\r\n  <tr mat-header-row *matHeaderRowDef=\"displayedColumns; sticky:true\"></tr>\r\n  <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\r\n</table>\r\n<mat-paginator [length]=\"tableLength\" [pageIndex]=\"0\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"[10,20, 50, 100]\" [showFirstLastButtons]=\"true\" (page)=\"paginate($event)\"></mat-paginator>\r\n\r\n\r\n<mat-menu #selectAllMenu=\"matMenu\">\r\n  <button mat-menu-item (click)=\"toggleAll('FIRST_50')\"> Select This Page ({{ tableLength < pageSize ? tableLength : pageSize }} ) </button>\r\n  <button mat-menu-item (click)=\"toggleAll('SELECT_ALL')\"> Select All ({{tableLength}}) </button>\r\n  <button mat-menu-item (click)=\"toggleAll('DESELECT_ALL')\"> Deselect All </button>\r\n</mat-menu>\r\n",
                styles: ["th.mat-header-cell{background-color:#fafafa;text-align:left;min-height:42px;max-width:200px;background-color:#2e75b6!important;color:#fff}td.mat-cell{text-align:left;max-width:150px;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;padding-left:5px}.select-container td.mat-cell{text-align:center!important}td.mat-cell:first-of-type,td.mat-footer-cell:first-of-type,th.mat-header-cell:first-of-type{padding-left:24px!important}.center{text-align:left}tr.mat-header-row{height:40px}.pointer{cursor:pointer}.header-cell{padding-top:8px;padding-bottom:8px;font-size:14px;font-weight:400;flex-wrap:wrap}.total-price{text-align:right!important}.link{color:#2196f3;text-decoration:underline}.arrow-down{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid #fff;position:relative;top:8px;cursor:pointer}.total-width{width:100%;text-align:right!important}p{margin:0}.tasks-done{color:#8b0000;position:relative;right:3px}.tasks-done,.tasks-total{text-decoration:underline;font-size:16px}.tasks-total{color:#4d5d66}.total-header{display:flex;justify-content:flex-end;font-size:14px;font-weight:400;flex-wrap:wrap;padding-left:10px;position:relative;right:20px}:host ::ng-deep .mat-sort-header-arrow{color:#fff}:host ::ng-deep .select-container .mat-checkbox .mat-checkbox-frame{border-color:#fff}.activities-font{font-size:16px}.slash{font-size:22px;position:relative;bottom:3px}.favorite{top:0!important}:host ::ng-deep .mat-cell .mat-icon{position:relative;top:16px;font-size:30px}.comment-number{position:link;cursor:pointer;color:#fff;position:relative;bottom:16px;left:6px}.comment-position{left:10px!important}.color-red-500{color:#f44336}.color-orange-500{color:#ff9800}.color-blue-500{color:#2196f3}.color-pink-500{color:#e91e63}.color-purple{color:#9c27b0}.width-60{width:60px}.width-90{width:90px}.width-120{width:120px}.width-150{width:150px}.padding-right-8{padding-right:8px}.paddding-left-4{padding-left:4px}.text-align-right{text-align:right}.arrow-down-total-price{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid #fff;position:relative;top:6px;left:4px;cursor:pointer}.product-image-wide{height:auto;max-height:40px!important;max-width:40px!important;margin-right:15px}"]
            },] }
];
KanbanProductsListComponent.ctorParameters = () => [];
KanbanProductsListComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    listDataSource: [{ type: Input }],
    displayedColumns: [{ type: Input }],
    pageSizeOptions: [{ type: Input }],
    tableLength: [{ type: Input }],
    page: [{ type: Input }],
    displayActionsBar: [{ type: Input }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    mappingFields: [{ type: Input }],
    selectClicked: [{ type: Output }],
    onFavoriteToggle: [{ type: Output }],
    onColumnClick: [{ type: Output }],
    onPaginateFire: [{ type: Output }],
    onSortFired: [{ type: Output }]
};
//# sourceMappingURL=kanban-products-list.component.js.map