import { Component, EventEmitter, Input, Output } from '@angular/core';
export class KanbanSavedSearchBarComponent {
    constructor() {
        this.savedSearchList = [];
        this.onSavedSearchSelect = new EventEmitter();
        this.fetchNextKanbanData = new EventEmitter();
        this.displayView = "";
        this.fetchLastKanbanData = new EventEmitter();
    }
    ngOnInit() {
    }
    /**
     * Emits event on selection of card.
     *
     * @param {SearchCardI} card
     * @returns {void}
     */
    onSelect(card) {
        this.onSavedSearchSelect.emit(card);
    }
    /**
     * Returns list from index 10 and beyond.
     *
     * @param {SearchCardI[]} searchList
     * @returns {SearchCardI[]}
     */
    getRemainingList(searchList) {
        if ((searchList === null || searchList === void 0 ? void 0 : searchList.length) > 10) {
            return searchList.slice(10);
        }
        return [];
    }
    fetchNextData() {
        this.fetchNextKanbanData.emit();
    }
    fetchLastData() {
        this.fetchLastKanbanData.emit();
    }
}
KanbanSavedSearchBarComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-kanban-saved-search-bar',
                template: "<div class=\"saved-search-container\" fxLayout=\"row\" fxLayoutAlign=\"start\" >\r\n  <span class=\"quick-search-box\"> <p>Quick Searches</p> </span>\r\n  <span *ngFor=\"let savedSearch of savedSearchList; let i = index\" (click)=\"onSelect(savedSearch)\" [ngClass]=\"{'saved-search-box': i < 10, 'selected-color': savedSearch.select}\">\r\n    <p *ngIf=\"i < 10\" class=\"saved-search-title\">  {{ savedSearch.title }} </p>\r\n   </span>\r\n\r\n  <span *ngIf=\"savedSearchList?.length > 10\" class=\"drop-down-container\">\r\n    <button mat-icon-button [matMenuTriggerFor]=\"remainingSearchList\" aria-label=\"saved-search-list\">\r\n      <mat-icon>keyboard_arrow_down</mat-icon>\r\n    </button>\r\n  </span>\r\n  <div class=\"container-next\" *ngIf=\"displayView === 'Schedule View'\">\r\n    <div class=\"icon-div\">\r\n      <button class=\"icon-btn\" (click)=\"fetchLastData()\">\r\n        <mat-icon class=\"collapsable-arrow\">arrow_back</mat-icon>\r\n      </button>\r\n    </div>\r\n    <p class=\"title\">Next Week</p>\r\n  <div class=\"icon-div\">\r\n    <button class=\"icon-btn\" (click)=\"fetchNextData()\">\r\n      <mat-icon class=\"collapsable-arrow\">arrow_forward</mat-icon>\r\n    </button>\r\n  </div>\r\n</div>\r\n</div>\r\n\r\n<mat-menu #remainingSearchList>\r\n  <div *ngFor=\"let list of this.getRemainingList(savedSearchList)\" >\r\n  <button mat-menu-item (click)=\"onSelect(list)\">\r\n    {{list.title }}\r\n  </button>\r\n  </div>\r\n</mat-menu>\r\n",
                styles: [".saved-search-container{width:100%;height:43px;border:1px solid #707070;white-space:nowrap;position:sticky;top:0;z-index:999999;background:#fff}.saved-search-container .selected-color{background-color:#ddd}.saved-search-container .quick-search-box{padding-left:15px;padding-right:15px;border-right:1px solid #707070;background-color:#ddd}.saved-search-container .saved-search-box{border-right:1px solid #707070;text-decoration:underline;padding-left:15px;padding-right:15px;max-width:15%}.saved-search-container .saved-search-box .saved-search-title{white-space:nowrap;overflow:hidden;text-overflow:ellipsis;cursor:pointer}.saved-search-container .drop-down-container{max-width:10%;border-left:1px solid #707070;position:absolute;right:0}.saved-search-container .container-next{display:flex;width:100%;flex-wrap:wrap;justify-content:flex-end;padding:10px;vertical-align:middle}.saved-search-container .container-next .title{margin-top:0;margin-bottom:0;line-height:24px;font-weight:700}.saved-search-container .container-next .icon-div{color:#3675b6}.saved-search-container .container-next .icon-div .collapsable-arrow{font-size:30px}.saved-search-container .container-next .icon-btn{border:none;background:no-repeat;cursor:pointer}.width-100{width:100%}"]
            },] }
];
KanbanSavedSearchBarComponent.ctorParameters = () => [];
KanbanSavedSearchBarComponent.propDecorators = {
    savedSearchList: [{ type: Input }],
    onSavedSearchSelect: [{ type: Output }],
    fetchNextKanbanData: [{ type: Output }],
    displayView: [{ type: Input }],
    fetchLastKanbanData: [{ type: Output }]
};
//# sourceMappingURL=kanban-saved-search-bar.component.js.map