import { Component, EventEmitter, Input, Output } from '@angular/core';
export class KanbanSearchCardComponent {
    constructor() {
        this.cardDetails = {
            id: '',
            title: '',
            filterList: [],
            isTab: false,
            isShared: false,
            order: 0,
            editPermission: true,
            isHide: false,
        };
        this.page = '';
        this.mappingFields = [];
        this.onDeleteCard = new EventEmitter();
        this.onSelectToggle = new EventEmitter();
        this.onQuickViewToggle = new EventEmitter();
        this.onSharedToggle = new EventEmitter();
        this.onHideCard = new EventEmitter();
    }
    ngOnInit() { }
    /**
     * Delete emits event.
     *
     * @returns {void}
     */
    onDeleteSearchCard() {
        this.onDeleteCard.emit(this.cardDetails);
    }
    onHideSearchCard() {
        console.log("this.cardDetails", this.cardDetails);
        this.onHideCard.emit(this.cardDetails);
    }
    /**
     * Select emits event.
     *
     * @returns {void}
     */
    onSelectEmitted() {
        this.onSelectToggle.emit(this.cardDetails);
    }
    /**
     * Enables or disables the quick for the saved search.
     *
     * @param {MatCheckbox} event
     * @returns {void}
     */
    onEnableQuickSearch(event) {
        this.onQuickViewToggle.emit({ card: this.cardDetails, value: event });
    }
    /**
     * Enables the share on the search card.
     *
     * @param {MatCheckbox} event
     * @returns {void}
     */
    onEnableShare(event) {
        this.onSharedToggle.emit({ card: this.cardDetails, value: event });
    }
}
KanbanSearchCardComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-kanban-search-card',
                template: "<div fxLayout=\"row\" class=\"box-container mat-elevation-z2\">\r\n  <div class=\"select-container\">\r\n      <div fxLayout=\"row\" class=\"drag-container\">\r\n        <mat-icon cdkDragHandle >drag_indicator</mat-icon>\r\n        <p class=\"select-title\" (click)=\"onSelectEmitted()\">Select </p>\r\n      </div>\r\n  </div>\r\n  <div fxLayout=\"column\" class=\"content-container\" fxLayoutAlign=\"space-between\">\r\n    <div style=\"padding-left: 13px;\">\r\n    <h3 *ngIf=\"cardDetails?.title\"> \"{{ cardDetails.title }}\" </h3>\r\n    <span class=\"filter-list-content\" >\r\n      <p *ngFor=\"let card of cardDetails.filterList; let i = index\"> {{ card.filterName | orderColumnNameMapper: page : mappingFields}} : {{ card.filterValue }} <span *ngIf=\"i !==cardDetails?.filterList.length-1\">, </span>  </p>\r\n    </span>\r\n    </div>\r\n    <div fxLayout=\"row\" class=\"footer-container\" fxLayoutAlign=\"space-between\">\r\n      <div fxLayout=\"row\" fxLayoutGap=\"6px\" class=\"checkbox-container\">\r\n        <mat-checkbox  (change)=\"onEnableQuickSearch($event)\" [checked]=\"cardDetails.isTab\"> Quick Search </mat-checkbox>\r\n        <mat-checkbox  (change)=\"onEnableShare($event)\" [checked]=\"cardDetails.isShared\"> Share </mat-checkbox>\r\n      </div>\r\n      <p *ngIf=\"!cardDetails.isHide\" (click)=\"onDeleteSearchCard()\" class=\"delete-btn\" > Delete</p>\r\n      <p *ngIf=\"cardDetails.isHide\" (click)=\"onHideSearchCard()\" class=\"delete-btn\" > Hide</p>\r\n    </div>\r\n  </div>\r\n</div>\r\n\r\n",
                styles: [".box-container{height:100px;width:100%;position:relative;color:#4d5d66;border:2px solid #ddd}.box-container .select-container{width:35%;position:relative;color:#fff;background-color:#2d313e}.box-container .select-container .drag-container{position:relative;top:35px}.box-container .select-container .drag-container .select-title{position:relative;top:3px;cursor:pointer}.box-container .content-container{width:65%;border-left:2px solid #2d313e;height:100%;padding-left:10px;padding-top:5px}.box-container .content-container .filter-list-content{width:95%;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;display:inline-flex}.box-container .content-container .footer-container{width:97%;margin:0 auto;border-top:1px solid #aaa}.box-container .content-container .footer-container .delete-btn{color:#8b0000;border-top:2px;cursor:pointer;font-size:11px;padding-top:2px}p{margin:0}h3{margin:0 0 3px}:host ::ng-deep .footer-container .checkbox-container .mat-checkbox-inner-container{width:14px!important;height:14px!important}:host ::ng-deep .footer-container .checkbox-container .mat-checkbox-label{font-size:10px!important}"]
            },] }
];
KanbanSearchCardComponent.ctorParameters = () => [];
KanbanSearchCardComponent.propDecorators = {
    cardDetails: [{ type: Input }],
    page: [{ type: Input }],
    mappingFields: [{ type: Input }],
    onDeleteCard: [{ type: Output }],
    onSelectToggle: [{ type: Output }],
    onQuickViewToggle: [{ type: Output }],
    onSharedToggle: [{ type: Output }],
    onHideCard: [{ type: Output }]
};
//# sourceMappingURL=kanban-search-card.component.js.map