import { animate, style, transition, trigger } from '@angular/animations';
import { moveItemInArray } from '@angular/cdk/drag-drop';
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { AdvancedSearchContainerData } from '../../models/common';
export class KanbanSearchComponent {
    constructor() {
        this.savedSearchList = [];
        this.display = false;
        this.advancedSearchFormData = {
            title: '',
            description: '',
            filters: [{ name: '', hint: '' }],
        };
        this.anteraFilterOptions = [];
        this.advancedSearchContainerData = {
            advancedSearchContainer: '',
            titleAdvancedSearch: '',
            excerptAdvancedSearch: ''
        };
        this.selectedIndex = 0;
        this.page = '';
        this.mappingFields = [];
        this.onCardDeleted = new EventEmitter();
        this.onSelectClicked = new EventEmitter();
        this.onAdvancedSearch = new EventEmitter();
        this.onSavedSearchQuickViewEnabled = new EventEmitter();
        this.onSavedSearchShare = new EventEmitter();
        this.onSavedSearchReorder = new EventEmitter();
        this.onCardHide = new EventEmitter();
        this.autoCompleteSearch = new EventEmitter();
        this.showProductDeleted = 0;
        this.reSynceNeeded = false;
        this.ontToggleResyncQBO = new EventEmitter();
        this.qboActive = false;
        this.onToggleAccountType = new EventEmitter();
    }
    ngOnInit() {
    }
    /**
     * Delete emitted.
     *
     * @param {SearchCardI} event
     * @returns {void}
     */
    onDeleteSavedSearch(event) {
        this.onCardDeleted.emit(event);
    }
    onHideSavedSearch(event) {
        this.onCardHide.emit(event);
    }
    /**
     * Select emitted.
     *
     * @param {SearchCardI} event
     * @returns {void}
     */
    onSelectBtnClicked(event) {
        this.onSelectClicked.emit(event);
    }
    /**
     * Emits advanced search form details.
     *
     * @param {any} searchValue
     * @returns {void}
     */
    emitAdvancedSearchValues(searchValue) {
        this.onAdvancedSearch.emit(searchValue);
    }
    /**
     * Search Card quick view enabled. Emit vard details and
     * checkbox value
     *
     * @param {any}
     * @returns {void}
     */
    onSavedSearchEnableQuickView(event) {
        this.onSavedSearchQuickViewEnabled.emit(event);
    }
    /**
     *
     */
    onSavedSearchCardOrderChange(event) {
        moveItemInArray(this.savedSearchList, event.previousIndex, event.currentIndex);
        this.savedSearchList.forEach((card, index) => card.order = index);
        this.onSavedSearchReorder.emit({ cardList: this.savedSearchList });
    }
    onShareToggle(event) {
        this.onSavedSearchShare.emit(event);
    }
    emitAutoComplete(event) {
        this.autoCompleteSearch.emit(event);
    }
    toggleResyncQBO(event) {
        this.ontToggleResyncQBO.emit(event);
    }
    changeAccType(event) {
        this.onToggleAccountType.emit(event);
    }
}
KanbanSearchComponent.decorators = [
    { type: Component, args: [{
                selector: 'antera-lib-kanban-search',
                template: "<mat-card *ngIf=\"display\" [@slideInOut] class=\"search-container\">\r\n  <mat-tab-group dynamicHeight [selectedIndex]=\"selectedIndex\">\r\n    <mat-tab label=\"Advanced Search\">\r\n      <ng-template matTabContent class=\"search-container-body\">\r\n        <antera-lib-kanban-search-advanced\r\n        [page]=\"page\"\r\n        [advancedSearchFormData]=\"advancedSearchFormData\"\r\n        [anteraFilterOptions]=\"anteraFilterOptions\"\r\n        [advancedSearchContainerData]=\"advancedSearchContainerData\"\r\n        (advancedSearchSavedValues)=\"emitAdvancedSearchValues($event)\"\r\n        (autoComplete)=\"emitAutoComplete($event)\"\r\n        [showProductDeleted]=\"showProductDeleted\"\r\n        (ontToggleResyncQBO)=\"toggleResyncQBO($event)\"\r\n        [reSynceNeeded]=\"reSynceNeeded\"\r\n        [qboActive]=\"qboActive\"\r\n        [mappingFields]=\"mappingFields\"\r\n        (onToggleAccountType)=\"changeAccType($event)\"\r\n        ></antera-lib-kanban-search-advanced>\r\n      </ng-template>\r\n    </mat-tab>\r\n    <mat-tab label=\"Saved Search\">\r\n      <ng-template matTabContent>\r\n        <div cdkDropList (cdkDropListDropped)=\"onSavedSearchCardOrderChange($event)\">\r\n          <div *ngFor=\"let card of savedSearchList\" class=\"margin-top-8\" >\r\n            <anterasoftware-kanban-search-card cdkDrag [cardDetails]=\"card\" [page]=\"page\" [mappingFields]=\"mappingFields\" (onSharedToggle)=\"onShareToggle($event)\"  (onQuickViewToggle)=\"onSavedSearchEnableQuickView($event)\" (onSelectToggle)=\"onSelectBtnClicked($event)\" (onDeleteCard)=\"onDeleteSavedSearch($event)\" (onHideCard)=\"onHideSavedSearch($event)\"></anterasoftware-kanban-search-card>\r\n          </div>\r\n        </div>\r\n      </ng-template>\r\n    </mat-tab>\r\n  </mat-tab-group>\r\n</mat-card>\r\n",
                animations: [
                    trigger('slideInOut', [
                        transition(':enter', [
                            style({ transform: 'translateX(-100%)' }),
                            animate('400ms ease-in', style({ transform: 'translateX(-100%)' }))
                        ]),
                        transition(':leave', [
                            animate('200ms ease-in', style({ transform: 'translateX(-100%)' }))
                        ])
                    ])
                ],
                styles: [".search-container{max-width:400px}.search-container-body{padding-top:750px;margin-top:530px}.margin-top-8{margin-top:8px}"]
            },] }
];
KanbanSearchComponent.ctorParameters = () => [];
KanbanSearchComponent.propDecorators = {
    savedSearchList: [{ type: Input }],
    display: [{ type: Input }],
    savedSearch: [{ type: Input }],
    advancedSearchFormData: [{ type: Input }],
    anteraFilterOptions: [{ type: Input }],
    advancedSearchContainerData: [{ type: Input }],
    selectedIndex: [{ type: Input }],
    page: [{ type: Input }],
    mappingFields: [{ type: Input }],
    onCardDeleted: [{ type: Output }],
    onSelectClicked: [{ type: Output }],
    onAdvancedSearch: [{ type: Output }],
    onSavedSearchQuickViewEnabled: [{ type: Output }],
    onSavedSearchShare: [{ type: Output }],
    onSavedSearchReorder: [{ type: Output }],
    onCardHide: [{ type: Output }],
    autoCompleteSearch: [{ type: Output }],
    showProductDeleted: [{ type: Input }],
    reSynceNeeded: [{ type: Input }],
    ontToggleResyncQBO: [{ type: Output }],
    qboActive: [{ type: Input }],
    onToggleAccountType: [{ type: Output }]
};
//# sourceMappingURL=kanban-search.component.js.map