import { Component, EventEmitter, Input, Output } from '@angular/core';
import * as moment from 'moment';
export class KanbanViewCardComponent {
    constructor() {
        this.dateFormatString = 'YYYY-MM-DD';
        this.timeFormatString = 'hh:mm a';
        this.onCardDetailsChange = new EventEmitter();
        this.onAssignArtwork = new EventEmitter();
        this.onDeleteArtwork = new EventEmitter();
        this.onEditArtwork = new EventEmitter();
        this.pinned = new EventEmitter();
        this.onOpenRelatedOrderDetailDialog = new EventEmitter();
        this.isOverdue = false;
        this.dueColor = '';
        this.dueFontColor = '';
        this.cardDetails = {
            select: false,
            title: '',
            dueDate: '',
            priority: '',
            orderNumber: [],
            status: '',
            tagList: [],
            smallImg: '',
            bigImg: '',
            id: '',
            estimated: '',
            assignee: '',
            assignedId: '',
            pinned: false,
            workOrderNo: '',
            workOrderId: '',
            designId: ''
        };
        this.orderNumbers = "";
    }
    ngOnInit() {
        this.isOverdue = (this.cardDetails.dueDate !== null) && (moment() > moment(new Date(this.cardDetails.dueDate)));
        if (this.cardDetails.orderNumber && this.cardDetails.orderNumber.length > 0) {
            let orderNumbers = this.cardDetails.orderNumber.map((value) => {
                return value.orderNum;
            });
            this.orderNumbers = orderNumbers.toString();
        }
        if (this.cardDetails.dueDate && this.cardDetails.dueDate !== '0000-00-00') {
            let cardDate = moment(this.cardDetails.dueDate).endOf('day');
            let curDate = moment().endOf('day');
            let diff = cardDate.diff(curDate, 'hours');
            switch (true) {
                // red past due or due today
                case diff < 0:
                    this.dueColor = 'red';
                    this.dueFontColor = '#ffffff';
                    break;
                //due today
                case diff == 0:
                    this.dueColor = 'orange';
                    this.dueFontColor = '#ffffff';
                    break;
                // tomorrow
                case diff >= 24 && diff <= 24 * 2:
                    this.dueColor = 'yellow';
                    break;
                // this week
                case diff >= 24 * 2 && diff <= 24 * 7:
                    this.dueColor = 'green';
                    this.dueFontColor = '#ffffff';
                    break;
                // next week
                case diff >= 24 * 7 && diff <= 24 * 14:
                    this.dueColor = 'blue';
                    this.dueFontColor = '#ffffff';
                    break;
                // this month
                case diff >= 24 * 14 && diff <= 24 * 30:
                    this.dueColor = 'black';
                    this.dueFontColor = '#ffffff';
                    break;
                default:
                    this.dueColor = 'gray';
                    break;
            }
        }
    }
    /**
     * Emits event on check box select.
     *
     * @returns {void}
     */
    onCheckBoxSelected(event) {
        this.onCardDetailsChange.emit(this.cardDetails);
    }
    assignArtwork(artwork) {
        this.onAssignArtwork.emit(artwork);
    }
    deleteArtwork(artwork) {
        this.onDeleteArtwork.emit(artwork);
    }
    editArtwork(artwork) {
        this.onEditArtwork.emit(artwork);
    }
    /* public onToggle(event: MatCheckbox, swimLaneIndex: number){
      this.swimLaneList[swimLaneIndex]?.cards.forEach((card: KanbanViewCardI) => card.select = event.checked);
      this.selectClicked.emit(this.swimLaneList);
    } */
    onPin(ev) {
        ev.stopPropagation();
        this.cardDetails.pinned = !this.cardDetails.pinned;
        this.pinned.emit(this.cardDetails);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
    openRelatedOrderDetailDialog(orderId, cardDetails) {
        let data = {
            orderId: orderId,
            cardDetails: cardDetails
        };
        this.onOpenRelatedOrderDetailDialog.emit(data);
    }
}
KanbanViewCardComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-kanban-view-card',
                template: "<mat-card>\r\n    <div class=\"top-bar\" [ngStyle]=\"{'background-color':dueColor, 'color': dueFontColor}\">\r\n        <!-- <mat-checkbox [(ngModel)]=\"cardDetails.select\" class=\"checkbox-position\" (change)=\"onCheckBoxSelected($event)\"></mat-checkbox> -->\r\n        <span class=\"top-container\">\r\n            Due Date: {{ getDateFormat(cardDetails.dueDate) }}\r\n        </span>\r\n    </div>\r\n\r\n    <div fxLayout=\"row\" fxLayoutAlign=\"space-between\">\r\n        <div fxLayout=\"row\" class=\"art-header\">\r\n            <div fxLayout=\"column\" class=\"header-container\">\r\n                <span><mat-checkbox [(ngModel)]=\"cardDetails.select\" class=\"checkbox-position\" (change)=\"onCheckBoxSelected($event)\"></mat-checkbox>{{ cardDetails.name }}</span>\r\n                <h4 class=\"art-title\">  </h4>\r\n                <!-- <p class=\"due-date\"> Due: {{ getDateFormat(cardDetails.dueDate, true, false, true) }} </p> -->\r\n            </div>\r\n        </div>\r\n        <div>\r\n            \r\n            <mat-icon  [matMenuTriggerFor]=\"openCardMenu\" aria-hidden=\"false\" aria-label=\"Example home icon\">more_vert</mat-icon>\r\n            <mat-menu #openCardMenu=\"matMenu\">\r\n                <button mat-menu-item (click)=\"assignArtwork(cardDetails)\">\r\n                    <span>Assign Artwork</span>\r\n                </button>\r\n                <button mat-menu-item (click)=\"deleteArtwork(cardDetails)\">\r\n                    <span>Delete</span>\r\n                </button>\r\n                <button mat-menu-item (click)=\"editArtwork(cardDetails)\">\r\n                    <span>Edit</span>\r\n                </button>\r\n            </mat-menu>\r\n            <span class=\"mt-8\"><a aria-label=\"pin\" (click)=\"onPin($event)\"><mat-icon *ngIf=\"cardDetails.pinned\">star</mat-icon><mat-icon *ngIf=\"!cardDetails.pinned\">star_border</mat-icon></a></span>\r\n        </div>\r\n    </div>\r\n    <mat-card-content>\r\n        <img (click)=\"editArtwork(cardDetails)\" width=\"240\" height=\"300\" class=\"img-flex\" [src]=\"cardDetails?.bigImg\"  [default]= \"'images/product-image-placeholder.png'\">\r\n    </mat-card-content>\r\n    <div fxLayout=\"row\" fxLayoutAlign=\"space-around\" class=\"status-container\">\r\n        <div class=\"status-inline\">\r\n            <p class=\"bold\"> Status: </p>\r\n            <p> {{cardDetails.status }} </p>\r\n        </div>\r\n        <div class=\"status-inline\">\r\n            <p class=\"bold\"> Priority</p>\r\n            <p> {{ cardDetails.priority }} </p>\r\n        </div>\r\n        <div class=\"status-inline\">\r\n            <p class=\"bold\"> Order#</p>\r\n            <p *ngIf=\"orderNumbers != ''\"> <a class=\"accent-900-fg\" [matTooltip]=\"orderNumbers\"  [matTooltipPosition]=\"'above'\"\r\n                [matTooltipClass]=\"'order-row-tooltip'\"\r\n                (click)=\"openRelatedOrderDetailDialog(cardDetails.orderNumber[0]?.orderId, cardDetails)\">\r\n                {{cardDetails.orderNumber[0]?.orderNum}}</a></p>\r\n            <p *ngIf=\"orderNumbers == ''\"> <a mat-button class=\"accent-900-fg\"\r\n                (click)=\"openRelatedOrderDetailDialog(cardDetails.orderNumber[0]?.orderId, cardDetails)\">\r\n                {{cardDetails.orderNumber[0]?.orderNum}}</a></p>\r\n        </div>\r\n        <div class=\"status-inline\">\r\n            <p class=\"bold\"> Work Order #</p>\r\n            <p> <a class=\"link\" [routerLink]=\"['/productions/', cardDetails.workOrderId]\">{{ cardDetails.workOrderNo }} </a></p>\r\n        </div>\r\n    </div>\r\n\r\n    <div class=\"footer-container\">\r\n        <p class=\"bold\"> Tags </p>\r\n        <p *ngFor=\"let tag of cardDetails.tagList\" class=\"tag\"> {{ tag }} </p>\r\n    </div>\r\n</mat-card>\r\n",
                styles: [".top-bar{display:flex;flex-direction:row;top:0;left:0;margin-bottom:5px;background-color:red;text-align:center;padding:5px 0;font-size:12px;font-weight:400}.top-bar,.top-bar .top-container{width:100%}.top-bar .checkbox-position{position:relative;bottom:5px}.tag{display:inline;font-size:10px;color:#008fcc}.img-flex{width:100%;height:100px;-o-object-fit:contain;object-fit:contain;cursor:pointer}.mat-card{border-radius:0!important;padding:0}.bold{font-weight:700}p{font-size:10px;margin:0}.status-inline{flex-direction:column;text-align:center;width:1 fr}.footer-container{padding:12px}.status-container{background-color:#f7f7f7;margin-left:-16px;margin-right:-16px;padding:12px}.due-date{font-family:Helvetica Neue;font-size:11px;color:#aaa;margin-top:-18px;margin-left:2px}.header-container{padding-left:5px}.art-title{margin-top:0;font-size:14px;margin-bottom:10px}.art-image{max-width:100%;max-height:100%}.art-header{margin-bottom:10px}.art-header .mat-checkbox{display:inline;float:left;padding:0 2px}"]
            },] }
];
KanbanViewCardComponent.ctorParameters = () => [];
KanbanViewCardComponent.propDecorators = {
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    onCardDetailsChange: [{ type: Output }],
    onAssignArtwork: [{ type: Output }],
    onDeleteArtwork: [{ type: Output }],
    onEditArtwork: [{ type: Output }],
    pinned: [{ type: Output }],
    onOpenRelatedOrderDetailDialog: [{ type: Output }],
    cardDetails: [{ type: Input }]
};
//# sourceMappingURL=kanban-view-card.component.js.map