import { Component, EventEmitter, Input, Output } from '@angular/core';
import * as moment from 'moment';
export class OpportunitiesKanbanViewCardComponent {
    constructor() {
        this.onCardDetailsChange = new EventEmitter();
        this.editCardDetails = new EventEmitter();
        this.dateFormatString = 'YYYY-MM-DD';
        this.timeFormatString = 'hh:mm a';
        this.dueColor = '';
        this.dueFontColor = '';
        this.cardDetails = {
            select: false,
            id: '',
            name: '',
            opportunityType: '',
            salesStage: '',
            amount: '',
            accountName: '',
            contactName: '',
            created: '',
            dateClosed: ''
        };
    }
    ngOnInit() {
        if (this.cardDetails.dateClosed && this.cardDetails.dateClosed !== '0000-00-00') {
            let cardDate = moment(this.cardDetails.dateClosed).endOf('day');
            let curDate = moment().endOf('day');
            let diff = cardDate.diff(curDate, 'hours');
            switch (true) {
                // red past due or due today
                case diff < 0:
                    this.dueColor = 'red';
                    this.dueFontColor = '#ffffff';
                    break;
                //due today
                case diff == 0:
                    this.dueColor = 'orange';
                    this.dueFontColor = '#ffffff';
                    break;
                // tomorrow
                case diff >= 24 && diff <= 24 * 2:
                    this.dueColor = 'yellow';
                    this.dueFontColor = '#000000';
                    break;
                // this week
                case diff >= 24 * 2 && diff <= 24 * 7:
                    this.dueColor = 'green';
                    this.dueFontColor = '#ffffff';
                    break;
                // next week
                case diff >= 24 * 7 && diff <= 24 * 14:
                    this.dueColor = 'blue';
                    this.dueFontColor = '#ffffff';
                    break;
                // this month
                case diff >= 24 * 14 && diff <= 24 * 30:
                    this.dueColor = 'black';
                    this.dueFontColor = '#ffffff';
                    break;
                default:
                    this.dueColor = 'gray';
                    this.dueFontColor = '#ffffff';
                    break;
            }
        }
    }
    onCheckBoxSelected(event) {
        this.onCardDetailsChange.emit(this.cardDetails);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
    editCard(lead) {
        this.editCardDetails.emit(lead);
    }
}
OpportunitiesKanbanViewCardComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-opportunities-kanban-view-card',
                template: "<mat-card class=\"swimlane-card\">\r\n    <mat-card-header class=\"card-header\" [ngStyle]=\"{'background-color':dueColor, 'color': dueFontColor}\">\r\n      <mat-card-title class=\"title-due-date\">\r\n        Close Date: {{ getDateFormat(cardDetails.dateClosed) }}</mat-card-title>\r\n    </mat-card-header>\r\n  \r\n    <!-- <a class=\"link\" [routerLink]=\"['/products/', cardDetails?.id]\"><img mat-card-image [src]=\"cardDetails?.image\" onError=\"this.src= 'assets/images/ecommerce/placeholder-image.png'\"/></a> --> \r\n    <mat-card-content>\r\n        <div fxLayout=\"row\" class=\"art-header\">      \r\n          <div fxLayout=\"column\" class=\"card-content\">\r\n            <div class=\"list-card-name condensed\"\r\n              fxLayout=\"row\" \r\n              fxLayoutAlign=\"space-between center\"\r\n              >\r\n              <div fxLayout=\"row\"\r\n                  fxLayoutAlign=\"space-between center\">\r\n                 \r\n                  <span><mat-checkbox [(ngModel)]=\"cardDetails.select\" class=\"checkbox-position\" (change)=\"onCheckBoxSelected($event)\"></mat-checkbox>{{ cardDetails.name }}</span>\r\n              </div>\r\n              <span class=\"accent-800-fg\">${{cardDetails.amount | number }}</span>\r\n          </div>\r\n            <span class=\"content-span\" (click)=\"editCard(card)\">\r\n              {{ cardDetails.opportunityType }} <br>\r\n              {{ cardDetails.salesStage }} <br>\r\n              {{ cardDetails.accountName }} <br>\r\n              {{ cardDetails.contactName }} <br>\r\n              {{ getDateFormat(cardDetails.created, true, false, true) }}<br>\r\n              <span></span>\r\n            </span>\r\n          </div>\r\n        </div>\r\n    </mat-card-content>\r\n  \r\n  </mat-card>",
                styles: ["@import url(\"https://fonts.googleapis.com/css2?family=Roboto:wght@100;300;400;700&display=swap\");.swimlane-card{background-color:#fff;border-radius:0;border:1px solid #ddd;box-shadow:6px 1px 0 #b5b5b5;padding:0;margin:5px}.swimlane-card ::ng-deep .mat-card-header{border-bottom:1px solid #ddd;background-color:#f4ffb9}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text{padding:0;margin:0;width:100%;text-align:center}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text .mat-card-title{margin-top:8px;color:\"#ffffff\";text-align:center;font-size:12px;padding:0;font-weight:100;margin-bottom:0;line-height:24px;font-weight:400;display:inline}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text .mat-checkbox{display:inline;float:left;padding:0 2px}.swimlane-card ::ng-deep .mat-card-content{font-size:14px;font-weight:400;padding:8px 0;white-space:break-spaces}.swimlane-card ::ng-deep .mat-card-image{margin:0 auto!important;padding:10px;display:block;width:50%!important}.swimlane-card .title-due-date{font-weight:700}.swimlane-card .list-card-name{font-size:14px}.swimlane-card .list-card-name .mat-checkbox{float:left;margin-right:6px}.swimlane-card .accent-800-fg{font-weight:550;color:#0277bd!important}.swimlane-card .content-span{margin-left:15px}.cdk-drag-preview{box-sizing:border-box;border-radius:4px;box-shadow:0 5px 5px -3px rgba(0,0,0,.2),0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 2px rgba(0,0,0,.12)}.cdk-drag-placeholder{opacity:0}.cdk-drag-animating{transition:transform .25s cubic-bezier(0,0,.2,1)}.example-box:last-child{border:none}.example-list.cdk-drop-list-dragging .example-box:not(.cdk-drag-placeholder){transition:transform .25s cubic-bezier(0,0,.2,1)}.card-content{width:100%;padding:5px}.mat-star-icon{float:right}"]
            },] }
];
OpportunitiesKanbanViewCardComponent.propDecorators = {
    onCardDetailsChange: [{ type: Output }],
    editCardDetails: [{ type: Output }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    cardDetails: [{ type: Input }]
};
//# sourceMappingURL=opportunities-kanban-view-card.component.js.map