import { Component, EventEmitter, Input, Output, ViewChild } from '@angular/core';
import { MatSort } from '@angular/material/sort';
import { MatTableDataSource } from '@angular/material/table';
import * as moment from 'moment';
export class OpportunitiesListViewComponent {
    constructor() {
        this.sort = {};
        this.listDataSource = [];
        this.displayedColumns = [];
        this.pageSizeOptions = [];
        this.tableLength = 0;
        this.page = '';
        this.displayActionsBar = false;
        this.dateFormatString = 'YYYY-MM-DD';
        this.timeFormatString = 'hh:mm a';
        this.mappingFields = [];
        this.paginationList = ['10', '20', '50', '100'];
        this.selectClicked = new EventEmitter();
        this.onColumnClick = new EventEmitter();
        this.onPaginateFire = new EventEmitter();
        this.onSortFired = new EventEmitter();
        this.selectAll = false;
        this.pageSize = 50;
    }
    ngOnInit() {
        this.dataSource = new MatTableDataSource(this.listDataSource);
        this.appendColumns();
    }
    ngOnChanges() {
        this.appendColumns();
        this.dataSource = new MatTableDataSource(this.listDataSource);
    }
    appendColumns() {
        const standardColumns = ['select'];
        standardColumns.forEach((colName) => {
            var _a;
            if (!((_a = this.displayedColumns) === null || _a === void 0 ? void 0 : _a.includes(colName))) {
                this.displayedColumns.unshift(colName);
            }
        });
    }
    toggleAll(selectType, checkbox, selectedRow) {
        switch (selectType) {
            case 'SINGLE':
                this.dataSource.data.find((row) => row.id === (selectedRow === null || selectedRow === void 0 ? void 0 : selectedRow.id)).select = checkbox === null || checkbox === void 0 ? void 0 : checkbox.checked;
                break;
            case 'FIRST_50':
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'SELECT_ALL':
                this.selectAll = true;
                this.dataSource.data.forEach((data) => (data.select = true));
                break;
            case 'DESELECT_ALL':
                this.selectAll = false;
                this.dataSource.data.forEach((data) => (data.select = false));
                break;
            case 'SELECT_ALL_TOGGLE':
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                selectType = this.selectAll ? 'SELECT_ALL' : 'DESELECT_ALL';
                break;
            default:
                this.selectAll = !this.selectAll;
                this.dataSource.data.forEach((data) => (data.select = this.selectAll));
                break;
        }
        this.selectClicked.emit({ data: this.dataSource.data, selectType });
    }
    onColumnClicked(element, columnName) {
        this.onColumnClick.emit({ columnName, rowSelected: element });
    }
    paginate(event) {
        const paginateObj = {
            offset: event.pageIndex,
            limit: event.pageSize,
        };
        this.pageSize = event.pageSize;
        this.onPaginateFire.emit(paginateObj);
    }
    onListViewSort(event) {
        this.onSortFired.emit(event);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
}
OpportunitiesListViewComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-opportunities-list-view',
                template: "<table mat-table [dataSource]=\"dataSource\" matSort (matSortChange)=\"onListViewSort($event)\" class=\"mat-elevation-z8\" [ngClass]=\"{'fixedHeader': displayActionsBar}\" style=\"width:100%\">\r\n\r\n    <ng-container matColumnDef=\"select\">\r\n      <th mat-header-cell  *matHeaderCellDef class=\"select-container width-120 padding-right-8\">\r\n        <div fxLayout=\"row\" fxLayoutGap=\"4px\">\r\n          <mat-checkbox (change)=\"toggleAll('SELECT_ALL_TOGGLE')\" [checked]=\"selectAll\" > </mat-checkbox>\r\n          <div class=\"arrow-down\" [matMenuTriggerFor]=\"selectAllMenu\"> </div>\r\n        </div>\r\n      </th>\r\n      <td mat-cell *matCellDef=\"let element\">\r\n        <mat-checkbox  (change)=\"toggleAll('SINGLE',$event, element)\" [checked]=\"element?.select\"> </mat-checkbox>\r\n      </td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"name\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'name' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'name')\" *matCellDef=\"let element\" [matTooltip]=\"element?.name\"><p class=\"text-truncate\"> {{element?.name}} </p></td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"accountName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'accountName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'accountName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.accountName\"><p class=\"text-truncate\">{{element?.accountName}}</p></td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"contactName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'contactName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'contactName')\" *matCellDef=\"let element\"  [matTooltip]=\"element?.contactName\"><p class=\"text-truncate\"> {{element?.contactName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"leadSource\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'leadSource' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'leadSource')\" *matCellDef=\"let element\" [matTooltip]=\"element?.leadSource\"><p class=\"text-truncate\"> {{element?.leadSource}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"opportunityType\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'opportunityType' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'opportunityType')\" *matCellDef=\"let element\" [matTooltip]=\"element?.opportunityType\"><p class=\"text-truncate\"> {{element?.opportunityType}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"salesStage\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'salesStage' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'salesStage')\" *matCellDef=\"let element\" [matTooltip]=\"element?.salesStage\"><p class=\"text-truncate\"> {{element?.salesStage}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"amount\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'amount' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'amount')\" *matCellDef=\"let element\" [matTooltip]=\"element?.amount\"><p class=\"text-truncate\"> {{element?.amount}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"salesRep\">\r\n        <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'salesRep' | orderColumnNameMapper : page : mappingFields }}</th>\r\n        <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'salesRep')\" *matCellDef=\"let element\" [matTooltip]=\"element?.salesRep\"><p class=\"text-truncate\"> {{element?.salesRep}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"dateCreated\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'dateCreated' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dateCreated')\" *matCellDef=\"let element\" [matTooltip]=\"element?.dateCreated\"><p class=\"text-truncate\"> {{ getDateFormat(element?.dateCreated, true, false, true) }} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"opportunityNo\">\r\n        <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'opportunityNo' | orderColumnNameMapper : page : mappingFields }}</th>\r\n        <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'opportunityNo')\" *matCellDef=\"let element\" [matTooltip]=\"element?.opportunityNo\"><p class=\"text-truncate\"> {{element?.opportunityNo}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"dateModified\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'dateModified' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dateModified')\" *matCellDef=\"let element\" [matTooltip]=\"element?.dateModified\"><p class=\"text-truncate\"> {{ getDateFormat(element?.dateModified, true, false, true) }} </p></td>\r\n    </ng-container>\r\n\r\n\r\n    <ng-container matColumnDef=\"probability\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'probability' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'probability')\" *matCellDef=\"let element\" [matTooltip]=\"element?.probability\"><p class=\"text-truncate\"> {{element?.probability}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"productionManagerName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'productionManagerName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'productionManagerName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.productionManagerName\"><p class=\"text-truncate\"> {{element?.productionManagerName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"salesManagerName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'salesManagerName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'salesManagerName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.salesManagerName\"><p class=\"text-truncate\"> {{element?.salesManagerName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"assignedSourcingRep\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'assignedSourcingRep' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'assignedSourcingRep')\" *matCellDef=\"let element\" [matTooltip]=\"element?.assignedSourcingRep\"><p class=\"text-truncate\"> {{element?.assignedSourcingRep}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"csrName\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef>{{ 'csrName' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'csrName')\" *matCellDef=\"let element\" [matTooltip]=\"element?.csrName\"><p class=\"text-truncate\"> {{element?.csrName}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"createdBy\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'createdBy' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'createdBy')\" *matCellDef=\"let element\" [matTooltip]=\"element?.createdBy\"><p class=\"text-truncate\"> {{element?.createdBy}} </p></td>\r\n    </ng-container>\r\n\r\n    <ng-container matColumnDef=\"dateClosed\">\r\n      <th mat-header-cell class=\"header-cell\" mat-sort-header *matHeaderCellDef> {{ 'dateClosed' | orderColumnNameMapper : page : mappingFields }}</th>\r\n      <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'dateClosed')\" *matCellDef=\"let element\" [matTooltip]=\"element?.dateClosed\"><p class=\"text-truncate\"> {{ getDateFormat(element?.dateClosed) }} </p></td>\r\n    </ng-container>\r\n\r\n  <ng-container matColumnDef='inhandsDate'>\r\n    <th mat-header-cell class='header-cell' mat-sort-header *matHeaderCellDef> {{ 'inhandsDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'inhandsDate')\" *matCellDef='let element' [matTooltip]='element?.inhandsDate'><p class='text-truncate'> {{ getDateFormat(element?.inhandsDate) }} </p></td>\r\n  </ng-container>\r\n\r\n  <ng-container matColumnDef='eventDate'>\r\n    <th mat-header-cell class='header-cell' mat-sort-header *matHeaderCellDef> {{ 'eventDate' | orderColumnNameMapper : page : mappingFields }}</th>\r\n    <td mat-cell class=\"pointer\" (click)=\"onColumnClicked(element, 'eventDate')\" *matCellDef='let element' [matTooltip]='element?.eventDate'><p class='text-truncate'> {{ getDateFormat(element?.eventDate) }} </p></td>\r\n  </ng-container>\r\n\r\n  <tr mat-header-row *matHeaderRowDef=\"displayedColumns; sticky:true\"></tr>\r\n    <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\r\n  </table>\r\n  <mat-paginator [length]=\"tableLength\" [pageIndex]=\"0\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"paginationList\" [showFirstLastButtons]=\"true\" (page)=\"paginate($event)\"></mat-paginator>\r\n\r\n\r\n  <mat-menu #selectAllMenu=\"matMenu\">\r\n    <button mat-menu-item (click)=\"toggleAll('FIRST_50')\"> Select This Page ({{ tableLength < pageSize ? tableLength : pageSize }} ) </button>\r\n    <button mat-menu-item (click)=\"toggleAll('SELECT_ALL')\"> Select All ({{tableLength}}) </button>\r\n    <button mat-menu-item (click)=\"toggleAll('DESELECT_ALL')\"> Deselect All </button>\r\n  </mat-menu>\r\n\r\n",
                styles: [".mat-table{table-layout:fixed;width:100%}th.mat-header-cell{background-color:#fafafa;text-align:left;min-height:42px;max-width:200px;background-color:#2e75b6!important;color:#fff}td.mat-cell :not(:first-child){text-align:left;max-width:150px;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;padding-left:5px}td.mat-cell:first-of-type,td.mat-footer-cell:first-of-type,th.mat-header-cell:first-of-type{padding-left:24px!important}.center{text-align:left}tr.mat-header-row{height:40px}.pointer{cursor:pointer}.header-cell{padding-top:8px;padding-bottom:8px;font-size:14px;font-weight:400;flex-wrap:wrap}.total-price{text-align:right!important}.link{color:#2196f3;text-decoration:underline}.arrow-down{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid #fff;position:relative;top:8px;cursor:pointer}.total-width{width:100%;text-align:right!important}p{margin:0}.tasks-done{color:#8b0000;position:relative;right:3px}.tasks-done,.tasks-total{text-decoration:underline;font-size:16px}.tasks-total{color:#4d5d66}.total-header{display:flex;justify-content:flex-end;font-size:14px;font-weight:400;flex-wrap:wrap;padding-left:10px}::ng-deep .mat-sort-header-arrow{color:#fff}::ng-deep .select-container .mat-checkbox .mat-checkbox-frame{border-color:#fff}.activities-font{font-size:16px}.slash{font-size:22px;position:relative;bottom:3px}.favorite{top:0!important}::ng-deep .mat-cell .mat-icon{position:relative;top:16px;font-size:30px}.comment-number{position:link;cursor:pointer;color:#fff;position:relative;bottom:16px;left:6px}.comment-position{left:10px!important}.color-red-500{color:#f44336}.color-orange-500{color:#ff9800}.color-blue-500{color:#2196f3}.color-pink-500{color:#e91e63}.color-purple{color:#9c27b0}.width-60{width:60px}.width-90{width:90px}.width-120{width:120px}.width-150{width:150px}.padding-right-8{padding-right:8px}.paddding-left-4{padding-left:4px}.text-align-right{text-align:right}.artwork-image-wide{height:auto;max-height:40px;max-width:40px}.text-truncate{white-space:nowrap;text-overflow:ellipsis;overflow:hidden}::ng-deep th.mat-header-cell,td.mat-cell,td.mat-footer-cell{width:150px;padding-left:6px}"]
            },] }
];
OpportunitiesListViewComponent.ctorParameters = () => [];
OpportunitiesListViewComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    listDataSource: [{ type: Input }],
    displayedColumns: [{ type: Input }],
    pageSizeOptions: [{ type: Input }],
    tableLength: [{ type: Input }],
    page: [{ type: Input }],
    displayActionsBar: [{ type: Input }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    mappingFields: [{ type: Input }],
    paginationList: [{ type: Input }],
    selectClicked: [{ type: Output }],
    onColumnClick: [{ type: Output }],
    onPaginateFire: [{ type: Output }],
    onSortFired: [{ type: Output }]
};
//# sourceMappingURL=opportunities-list-view.component.js.map