import { Component, EventEmitter, Input, Output } from '@angular/core';
import * as moment from 'moment';
export class OrdersKanbanViewCardComponent {
    constructor() {
        this.onCardDetailsChange = new EventEmitter();
        this.pinned = new EventEmitter();
        this.dateFormatString = 'YYYY-MM-DD';
        this.timeFormatString = 'hh:mm a';
        this.cardDetails = {
            select: false,
            id: '',
            orderNo: '',
            orderIdentity: '',
            orderDate: '',
            accountName: '',
            salesPerson: '',
            contactName: '',
            kanbanStatus: "",
            inHandDateBy: ""
        };
        this.dueColor = '';
        this.dueFontColor = '';
    }
    ngOnInit() {
        if (this.cardDetails.inHandDateBy && this.cardDetails.inHandDateBy !== '0000-00-00') {
            let cardDate = moment(this.cardDetails.inHandDateBy).endOf('day');
            let curDate = moment().endOf('day');
            let diff = cardDate.diff(curDate, 'hours');
            switch (true) {
                // red past due or due today
                case diff < 0:
                    this.dueColor = 'red';
                    this.dueFontColor = '#ffffff';
                    break;
                //due today
                case diff == 0:
                    this.dueColor = 'orange';
                    this.dueFontColor = '#ffffff';
                    break;
                // tomorrow
                case diff >= 24 && diff <= 24 * 2:
                    this.dueColor = 'yellow';
                    this.dueFontColor = '#000000';
                    break;
                // this week
                case diff >= 24 * 2 && diff <= 24 * 7:
                    this.dueColor = 'green';
                    this.dueFontColor = '#ffffff';
                    break;
                // next week
                case diff >= 24 * 7 && diff <= 24 * 14:
                    this.dueColor = 'blue';
                    this.dueFontColor = '#ffffff';
                    break;
                // this month
                case diff >= 24 * 14 && diff <= 24 * 30:
                    this.dueColor = 'black';
                    this.dueFontColor = '#ffffff';
                    break;
                default:
                    this.dueColor = 'gray';
                    this.dueFontColor = '#000000';
                    break;
            }
        }
    }
    onCheckBoxSelected(event) {
        this.onCardDetailsChange.emit(this.cardDetails);
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
}
OrdersKanbanViewCardComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-orders-kanban-view-card',
                template: "<!-- <mat-card class=\"swimlane-card\">\r\n    <mat-card-header>\r\n      <mat-card-title class=\"title-due-date\" [ngStyle]=\"{'background-color':dueColor}\">In Hands Date: {{ getDateFormat(cardDetails.inHandDateBy, true, false, true) }}</mat-card-title>\r\n    </mat-card-header>\r\n  \r\n    <mat-card-content>\r\n        <div fxLayout=\"row\" class=\"art-header\">\r\n            <mat-checkbox [(ngModel)]=\"cardDetails.select\" class=\"checkbox-position\" (change)=\"onCheckBoxSelected($event)\"></mat-checkbox>  \r\n              <div fxLayout=\"column\" class=\"card-content\">\r\n                <span>\r\n                  Identity: {{ cardDetails.orderIdentity }} <br>                  \r\n                  Account: {{ cardDetails.accountName }} <br>\r\n                  Sales Rep: {{ cardDetails.salesPerson }} <br>\r\n                  Contact: {{ cardDetails.contactName }}<br>\r\n                </span>\r\n              </div>\r\n            </div>\r\n    </mat-card-content>\r\n  \r\n  </mat-card> -->\r\n\r\n  <mat-card class=\"swimlane-card\">\r\n    <mat-card-header class=\"card-header\" [ngStyle]=\"{'background-color':dueColor, 'color': dueFontColor}\">\r\n      <mat-card-title class=\"title-due-date\" [ngStyle]=\"{'background-color':dueColor}\">In Hands Date: {{ getDateFormat(cardDetails.inHandDateBy) }}</mat-card-title>\r\n    </mat-card-header>\r\n  \r\n    <!-- <a class=\"link\" [routerLink]=\"['/products/', cardDetails?.id]\"><img mat-card-image [src]=\"cardDetails?.image\" onError=\"this.src= 'assets/images/ecommerce/placeholder-image.png'\"/></a> --> \r\n    <mat-card-content>\r\n        <div fxLayout=\"row\" class=\"art-header\">\r\n          <mat-checkbox [(ngModel)]=\"cardDetails.select\" class=\"checkbox-position ml-12\" (change)=\"onCheckBoxSelected($event)\"></mat-checkbox>  \r\n            <div fxLayout=\"column\" class=\"card-content\" [routerLink]=\"['/e-commerce/orders', cardDetails.id]\">\r\n              <span>\r\n                Order #: {{ cardDetails.orderNo }} <br>\r\n                Identity: {{ cardDetails.orderIdentity }} <br>                  \r\n                Account: {{ cardDetails.accountName }} <br>\r\n                Sales Rep: {{ cardDetails.salesPerson }} <br>\r\n                Contact: {{ cardDetails.contactName }}<br>\r\n              </span>\r\n            </div>\r\n          </div>\r\n    </mat-card-content>\r\n  \r\n  </mat-card>",
                styles: ["@import url(\"https://fonts.googleapis.com/css2?family=Roboto:wght@100;300;400;700&display=swap\");.swimlane-card{background-color:#fff;border-radius:0;border:1px solid #ddd;box-shadow:6px 1px 0 #b5b5b5;padding:0;margin:5px}.swimlane-card ::ng-deep .mat-card-header{border-bottom:1px solid #ddd;background-color:#f4ffb9}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text{padding:0;margin:0;width:100%;text-align:center}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text .mat-card-title{margin-top:8px;color:\"#ffffff\";text-align:center;font-size:12px;padding:0;font-weight:100;margin-bottom:0;line-height:24px;font-weight:400;display:inline}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text .mat-checkbox{display:inline;float:left;padding:0 2px}.swimlane-card ::ng-deep .mat-card-content{font-size:14px;font-weight:400;padding:8px 0;white-space:break-spaces}.swimlane-card ::ng-deep .mat-card-image{margin:0 auto!important;padding:10px;display:block;width:50%!important}.swimlane-card .title-due-date{font-weight:700}.swimlane-card .list-card-name{font-size:14px}.swimlane-card .list-card-name .mat-checkbox{float:left;margin-right:6px}.swimlane-card .accent-800-fg{font-weight:550;color:#0277bd!important}.swimlane-card .content-span{margin-left:15px}.cdk-drag-preview{box-sizing:border-box;border-radius:4px;box-shadow:0 5px 5px -3px rgba(0,0,0,.2),0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 2px rgba(0,0,0,.12)}.cdk-drag-placeholder{opacity:0}.cdk-drag-animating{transition:transform .25s cubic-bezier(0,0,.2,1)}.example-box:last-child{border:none}.example-list.cdk-drop-list-dragging .example-box:not(.cdk-drag-placeholder){transition:transform .25s cubic-bezier(0,0,.2,1)}.card-content{width:100%;padding:5px}.mat-star-icon{float:right}"]
            },] }
];
OrdersKanbanViewCardComponent.ctorParameters = () => [];
OrdersKanbanViewCardComponent.propDecorators = {
    onCardDetailsChange: [{ type: Output }],
    pinned: [{ type: Output }],
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    cardDetails: [{ type: Input }]
};
//# sourceMappingURL=orders-kanban-view-card.component.js.map