import { Component, Input } from '@angular/core';
import * as moment from 'moment';
export class ProductionKanbanViewCardComponent {
    constructor() {
        this.defaultImg = '../../placeholder-image.png';
        this.isOverdue = false;
        this.dueColor = '';
        this.bgImageColor = '';
        this.bgContentColor = '';
        this.dateFormatString = 'DD/MM/YYYY';
        this.timeFormatString = 'hh:mm a';
        this.cardDetails = {
            select: false,
            id: '',
            customerName: '',
            job: '',
            order: '',
            type: '',
            product: '',
            image: '',
            dueDate: '',
            machineId: '',
            machineName: '',
            scheduleDate: '',
            status: '',
            quantity: '',
            pinned: false,
            statusId: '',
            statusName: '',
            batchMaster: 0,
        };
        this.dueFontColor = '';
    }
    ngOnInit() {
        this.isOverdue = (this.cardDetails.dueDate !== null) && (moment() > moment(new Date(this.cardDetails.dueDate)));
        if (this.cardDetails.status && this.cardDetails.status === 'Done') {
            this.bgImageColor = '#e9f6dd';
        }
        if (this.cardDetails.quantity && this.cardDetails.quantity !== '0') {
            this.bgContentColor = '#e9f6dd';
        }
        if (this.cardDetails.dueDate && this.cardDetails.dueDate !== '0000-00-00') {
            let cardDate = moment(this.cardDetails.dueDate).endOf('day');
            let curDate = moment().endOf('day');
            let diff = cardDate.diff(curDate, 'hours');
            switch (true) {
                // red past due or due today
                case diff < 0:
                    this.dueColor = 'red';
                    this.dueFontColor = '#ffffff';
                    break;
                //due today
                case diff == 0:
                    this.dueColor = 'orange';
                    this.dueFontColor = '#ffffff';
                    break;
                // tomorrow
                case diff >= 24 && diff <= 24 * 2:
                    this.dueColor = 'yellow';
                    this.dueFontColor = '#000000';
                    break;
                // this week
                case diff >= 24 * 2 && diff <= 24 * 7:
                    this.dueColor = 'green';
                    this.dueFontColor = '#ffffff';
                    break;
                // next week
                case diff >= 24 * 7 && diff <= 24 * 14:
                    this.dueColor = 'blue';
                    this.dueFontColor = '#ffffff';
                    break;
                // this month
                case diff >= 24 * 14 && diff <= 24 * 30:
                    this.dueColor = 'black';
                    this.dueFontColor = '#ffffff';
                    break;
                default:
                    this.dueColor = 'gray';
                    this.dueFontColor = '#000000';
                    break;
            }
        }
    }
    getDateFormat(date, includeTime = false, excludeTime = false, convert = false) {
        if (date == null || date == '' || date == '0000-00-00 00:00:00' || date == '0000-00-00' || date == '0000-00-00' || (String(date).indexOf("0000") > -1 && String(date).indexOf("+0000") < 0)) {
            return '';
        }
        if (convert) {
            if (includeTime) {
                return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(moment.utc(date).local().toDate()).format(this.dateFormatString);
                }
            }
        }
        else {
            if (includeTime) {
                return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
            }
            else {
                if (String(date).length > 10 && !excludeTime) {
                    return moment(date).format(this.dateFormatString + ' ' + this.timeFormatString);
                }
                else {
                    return moment(date).format(this.dateFormatString);
                }
            }
        }
    }
}
ProductionKanbanViewCardComponent.decorators = [
    { type: Component, args: [{
                selector: 'anterasoftware-production-kanban-view-card',
                template: "<mat-card class=\"swimlane-card\">\r\n    <mat-card-header>\r\n      <mat-card-title [ngStyle]=\"{'background-color':dueColor, 'color': dueFontColor}\">Due Date: {{ getDateFormat(cardDetails.dueDate) }}</mat-card-title>\r\n    </mat-card-header>\r\n\r\n    <a class=\"link\" [routerLink]=\"['/productions/', cardDetails?.id]\"><img mat-card-image [src]=\"cardDetails?.image\" onError=\"this.src= 'assets/images/ecommerce/placeholder-image.png'\"/></a> \r\n    <mat-card-content>\r\n      {{ cardDetails.customerName }} <br>\r\n      Job# {{ cardDetails.job }} <br>\r\n      Order# {{ cardDetails.order }} <br>\r\n      Type: {{ cardDetails.type }} <br>\r\n      Product: {{ cardDetails.product }}<br>\r\n    </mat-card-content>\r\n\r\n</mat-card>\r\n",
                styles: ["@import url(\"https://fonts.googleapis.com/css2?family=Roboto:wght@100;300;400;700&display=swap\");.swimlane-card{background-color:#fff;border-radius:0;border:1px solid #ddd;box-shadow:6px 1px 0 #b5b5b5;padding:0;margin:5px}.swimlane-card ::ng-deep .mat-card-header{border-bottom:1px solid #ddd}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text{padding:0;margin:0;width:100%}.swimlane-card ::ng-deep .mat-card-header .mat-card-header-text .mat-card-title{background-color:#f4ffb9;text-align:center;font-size:12px;padding:5px 0;font-weight:400;margin-bottom:0}.swimlane-card ::ng-deep .mat-card-content{font-size:14px;font-weight:400;padding:10px;white-space:break-spaces}.swimlane-card ::ng-deep .mat-card-image{margin:0 auto!important;padding:10px;display:block;width:50%!important}.cdk-drag-preview{box-sizing:border-box;border-radius:4px;box-shadow:0 5px 5px -3px rgba(0,0,0,.2),0 8px 10px 1px rgba(0,0,0,.14),0 3px 14px 2px rgba(0,0,0,.12)}.cdk-drag-placeholder{opacity:0}.cdk-drag-animating{transition:transform .25s cubic-bezier(0,0,.2,1)}.example-box:last-child{border:none}.example-list.cdk-drop-list-dragging .example-box:not(.cdk-drag-placeholder){transition:transform .25s cubic-bezier(0,0,.2,1)}"]
            },] }
];
ProductionKanbanViewCardComponent.ctorParameters = () => [];
ProductionKanbanViewCardComponent.propDecorators = {
    dateFormatString: [{ type: Input }],
    timeFormatString: [{ type: Input }],
    cardDetails: [{ type: Input }]
};
//# sourceMappingURL=production-kanban-view-card.component.js.map